@@ -10,29 +10,34 @@
 
 __docformat__ = 'restructuredtext'
 
-from unittest.mock import patch
-from nose.tools import assert_is_instance
-
 from os import mkdir
-from os.path import join as opj, exists, realpath
+from os.path import (
+    join as opj,
+)
 from ..helpers import get_repo_instance
 from ..helpers import strip_arg_from_argv
 
-from ...tests.utils import ok_, eq_, assert_cwd_unchanged, ok_clean_git, \
-    with_tempfile, SkipTest, with_testrepos
+from datalad.tests.utils import (
+    assert_is_instance,
+    eq_,
+    assert_cwd_unchanged,
+    with_testrepos,
+)
 from ...support.annexrepo import AnnexRepo
 from ...support.gitrepo import GitRepo
 from ...utils import chpwd, getpwd
+from ...utils import Path
 
 
 @assert_cwd_unchanged
 @with_testrepos('^basic_git$', flavors=['clone'])
 def test_get_repo_instance_git(path):
+    real_path = Path(path).resolve()
 
     # get instance from path
     repo = get_repo_instance(path, GitRepo)
     assert_is_instance(repo, GitRepo)
-    eq_(realpath(repo.path), realpath(path))
+    eq_(repo.pathobj, real_path)
 
     old_pwd = getpwd()
 
@@ -40,7 +45,7 @@ def test_get_repo_instance_git(path):
     chpwd(path)
     repo = get_repo_instance()
     assert_is_instance(repo, GitRepo)
-    eq_(realpath(repo.path), realpath(path))
+    eq_(repo.pathobj, real_path)
 
     # get instance from current subdir
     new_subdir = opj(path, "subdir")
@@ -49,7 +54,7 @@ def test_get_repo_instance_git(path):
     eq_(new_subdir, getpwd())
     repo = get_repo_instance()
     assert_is_instance(repo, GitRepo)
-    eq_(realpath(repo.path), realpath(path))
+    eq_(repo.pathobj, real_path)
 
     chpwd(old_pwd)
 
@@ -57,11 +62,12 @@ def test_get_repo_instance_git(path):
 @assert_cwd_unchanged
 @with_testrepos('.*annex.*', flavors=['clone'])
 def test_get_repo_instance_annex(path):
+    real_path = Path(path).resolve()
 
     # get instance from path
     repo = get_repo_instance(path, AnnexRepo)
     assert_is_instance(repo, AnnexRepo)
-    eq_(realpath(repo.path), realpath(path))
+    eq_(repo.pathobj, real_path)
 
     old_pwd = getpwd()
 
@@ -69,7 +75,7 @@ def test_get_repo_instance_annex(path):
     chpwd(path)
     repo = get_repo_instance()
     assert_is_instance(repo, AnnexRepo)
-    eq_(realpath(repo.path), realpath(path))
+    eq_(repo.pathobj, real_path)
 
     # get instance from current subdir
     new_subdir = opj(path, "subdir")
@@ -78,7 +84,7 @@ def test_get_repo_instance_annex(path):
     eq_(new_subdir, getpwd())
     repo = get_repo_instance()
     assert_is_instance(repo, AnnexRepo)
-    eq_(realpath(repo.path), realpath(path))
+    eq_(repo.pathobj, real_path)
 
     chpwd(old_pwd)
 
