@@ -8,9 +8,7 @@
 # ## ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ##
 """Test functioning of the datalad main cmdline utility """
 
-from datalad.tests.utils import on_windows
-
-
+import os
 import re
 import sys
 from io import StringIO
@@ -23,16 +21,32 @@ from ..main import (
     _fix_datalad_ri,
 )
 from datalad import __version__
-from datalad.cmd import Runner
-from datalad.ui.utils import get_console_width
+from datalad.cmd import (
+    WitlessRunner as Runner,
+    StdOutErrCapture,
+)
+from datalad.ui.utils import (
+    get_console_width,
+    get_terminal_size,
+)
 from datalad.api import create
-from datalad.utils import chpwd
-from datalad.tests.utils import with_tempfile
-from datalad.tests.utils import assert_equal, assert_raises, in_, ok_startswith
-from datalad.tests.utils import assert_in
-from datalad.tests.utils import assert_re_in
-from datalad.tests.utils import assert_not_in
-from datalad.tests.utils import slow
+from datalad.utils import (
+    chpwd,
+    Path,
+)
+from datalad.tests.utils import (
+    on_windows,
+    with_tempfile,
+    assert_equal,
+    assert_raises,
+    in_,
+    ok_startswith,
+    assert_in,
+    assert_re_in,
+    assert_not_in,
+    slow,
+    SkipTest,
+)
 
 
 def run_main(args, exit_code=0, expect_stderr=False):
@@ -104,6 +118,10 @@ def test_help_np():
               'Plugins'}:
         assert_in(s, sections)
 
+    if not get_terminal_size()[0] or 0:
+        raise SkipTest(
+            "Could not determine terminal size, skipping the rest of the test")
+
     # none of the lines must be longer than 80 chars
     # TODO: decide on   create-sibling and possibly
     # rewrite-urls
@@ -171,25 +189,33 @@ def test_incorrect_options():
 
 def test_script_shims():
     runner = Runner()
+    # The EASY-INSTALL checks below aren't valid for editable installs. Use the
+    # existence of setup.py as an indication that install is _probably_
+    # editable. The file should always exist for editable installs, but it can
+    # also exist for non-editable installs when the tests are being executed
+    # from the top of the source tree.
+    setup_exists = (Path(datalad.__file__).parent.parent / "setup.py").exists()
     for script in [
         'datalad',
         'git-annex-remote-datalad-archives',
         'git-annex-remote-datalad']:
         if not on_windows:
             # those must be available for execution, and should not contain
-            which, _ = runner(['which', script])
+            which = runner.run(['which', script], protocol=StdOutErrCapture)['stdout']
             # test if there is no easy install shim in there
             with open(which.rstrip()) as f:
                 content = f.read()
         else:
             from distutils.spawn import find_executable
             content = find_executable(script)
-        assert_not_in('EASY', content) # NOTHING easy should be there
-        assert_not_in('pkg_resources', content)
+
+        if not setup_exists:
+            assert_not_in('EASY', content) # NOTHING easy should be there
+            assert_not_in('pkg_resources', content)
 
         # and let's check that it is our script
-        out, err = runner([script, '--version'])
-        version = (out + err).splitlines()[0].split(' ', 1)[1]
+        out = runner.run([script, '--version'], protocol=StdOutErrCapture)
+        version = (out['stdout'] + out['stderr']).splitlines()[0].split(' ', 1)[1]
         # we can get git and non git .dev version... so for now
         # relax
         get_numeric_portion = lambda v: [x for x in v.split('.') if x.isdigit()]
@@ -203,39 +229,36 @@ def test_script_shims():
 @with_tempfile(mkdir=True)
 def test_cfg_override(path):
     with chpwd(path):
+        cmd = ['datalad', 'wtf', '-s', 'some']
         # control
-        out, err = Runner()('datalad wtf -s some', shell=True)
+        out = Runner().run(cmd, protocol=StdOutErrCapture)['stdout']
         assert_not_in('datalad.dummy: this', out)
         # ensure that this is not a dataset's cfg manager
         assert_not_in('datalad.dataset.id', out)
         # env var
-        if on_windows:
-            cmd_str = 'set DATALAD_DUMMY=this&& datalad wtf -s some'
-        else:
-            cmd_str = 'DATALAD_DUMMY=this datalad wtf -s some'
-        out, err = Runner()(cmd_str, shell=True)
+        out = Runner(env=dict(os.environ, DATALAD_DUMMY='this')).run(
+            cmd, protocol=StdOutErrCapture)['stdout']
         assert_in('datalad.dummy: this', out)
         # cmdline arg
-        out, err = Runner()('datalad -c datalad.dummy=this wtf -s some', shell=True)
+        out = Runner().run([cmd[0], '-c', 'datalad.dummy=this'] + cmd[1:],
+                           protocol=StdOutErrCapture)['stdout']
         assert_in('datalad.dummy: this', out)
 
         # now create a dataset in the path. the wtf plugin will switch to
         # using the dataset's config manager, which must inherit the overrides
         create(dataset=path)
         # control
-        out, err = Runner()('datalad wtf -s some', shell=True)
+        out = Runner().run(cmd, protocol=StdOutErrCapture)['stdout']
         assert_not_in('datalad.dummy: this', out)
         # ensure that this is a dataset's cfg manager
         assert_in('datalad.dataset.id', out)
         # env var
-        if on_windows:
-            cmd_str = 'set DATALAD_DUMMY=this&& datalad wtf -s some'
-        else:
-            cmd_str = 'DATALAD_DUMMY=this datalad wtf -s some'
-        out, err = Runner()(cmd_str, shell=True)
+        out = Runner(env=dict(os.environ, DATALAD_DUMMY='this')).run(
+            cmd, protocol=StdOutErrCapture)['stdout']
         assert_in('datalad.dummy: this', out)
         # cmdline arg
-        out, err = Runner()('datalad -c datalad.dummy=this wtf -s some', shell=True)
+        out = Runner().run([cmd[0], '-c', 'datalad.dummy=this'] + cmd[1:],
+                           protocol=StdOutErrCapture)['stdout']
         assert_in('datalad.dummy: this', out)
 
 
