@@ -17,7 +17,6 @@ import logging
 import re
 from tempfile import TemporaryFile
 
-from datalad.cmd import GitWitlessRunner
 from datalad.interface.base import (
     Interface,
     build_doc,
@@ -46,7 +45,7 @@ from datalad.support.constraints import (
 from datalad.support.exceptions import CommandError
 from datalad.utils import (
     Path,
-    assure_list,
+    ensure_list,
 )
 
 from datalad.distribution.dataset import (
@@ -198,7 +197,7 @@ class Push(Interface):
             raise ValueError("'since' should point to commitish or use '^'.")
         # we resolve here, because we need to perform inspection on what was given
         # as an input argument further down
-        paths = [resolve_path(p, dataset) for p in assure_list(path)]
+        paths = [resolve_path(p, dataset) for p in ensure_list(path)]
 
         ds = require_dataset(
             dataset, check_installed=True, purpose='pushing')
@@ -378,9 +377,7 @@ def _datasets_since_(dataset, since, paths, recursive, recursion_limit):
 
 
 def _push(dspath, content, target, data, force, jobs, res_kwargs, pbars,
-          done_fetch=None, got_path_arg=False):
-    if not done_fetch:
-        done_fetch = set()
+          got_path_arg=False):
     force_git_push = force in ('all', 'gitpush')
 
     # nothing recursive in here, we only need a repo to work with
@@ -462,7 +459,7 @@ def _push(dspath, content, target, data, force, jobs, res_kwargs, pbars,
     depvar = 'remote.{}.datalad-publish-depends'.format(target)
     # list of remotes that are publication dependencies for the
     # target remote
-    publish_depends = assure_list(ds.config.get(depvar, []))
+    publish_depends = ensure_list(ds.config.get(depvar, []))
     if publish_depends:
         lgr.debug("Discovered publication dependencies for '%s': %s'",
                   target, publish_depends)
@@ -546,8 +543,7 @@ def _push(dspath, content, target, data, force, jobs, res_kwargs, pbars,
     # we know what to push and where, now dependency processing first
     for r in publish_depends:
         # simply make a call to this function again, all the same, but
-        # target is different, pass done_fetch to avoid duplicate
-        # and expensive calls to git-fetch
+        # target is different
         yield from _push(
             dspath,
             content,
@@ -558,7 +554,6 @@ def _push(dspath, content, target, data, force, jobs, res_kwargs, pbars,
             jobs,
             res_kwargs.copy(),
             pbars,
-            done_fetch=None,
             got_path_arg=got_path_arg,
         )
 
@@ -632,7 +627,11 @@ def _push(dspath, content, target, data, force, jobs, res_kwargs, pbars,
                 "Sync local annex branch from pushurl after remote "
                 'availability update.')
         repo.call_git(fetch_cmd)
-        repo.localsync(target)
+        # If no CommandError was raised, it means that remote has git-annex
+        # but local repo might not be an annex yet. Since there is nothing to "sync"
+        # from us, we just skip localsync without mutating repo into an AnnexRepo
+        if is_annex_repo:
+            repo.localsync(target)
     except CommandError as e:
         # it is OK if the remote doesn't have a git-annex branch yet
         # (e.g. fresh repo)
@@ -722,27 +721,35 @@ def _push_data(ds, target, content, data, force, jobs, res_kwargs,
             target,
         )
         return
+
+    ds_repo = ds.repo
+
     res_kwargs['target'] = target
     if not ds.config.get('.'.join(('remote', target, 'annex-uuid')), None):
         # this remote either isn't an annex,
         # or hasn't been properly initialized
-        # rather than barfing tons of messages for each file, do one
-        # for the entire dataset
-        yield dict(
-            res_kwargs,
-            action='copy',
-            status='impossible'
-            if force in ('all', 'checkdatapresent')
-            else 'notneeded',
-            message=(
-                "Target '%s' does not appear to be an annex remote",
-                target)
-        )
-        return
+        # given that there was no annex-ignore, let's try to init it
+        # see https://github.com/datalad/datalad/issues/5143 for the story
+        ds_repo.localsync(target)
+
+        if not ds.config.get('.'.join(('remote', target, 'annex-uuid')), None):
+            # still nothing
+            # rather than barfing tons of messages for each file, do one
+            # for the entire dataset
+            yield dict(
+                res_kwargs,
+                action='copy',
+                status='impossible'
+                if force in ('all', 'checkdatapresent')
+                else 'notneeded',
+                message=(
+                    "Target '%s' does not appear to be an annex remote",
+                    target)
+            )
+            return
 
     # it really looks like we will transfer files, get info on what annex
     # has in store
-    ds_repo = ds.repo
     # paths must be recoded to a dataset REPO root (in case of a symlinked
     # location
     annex_info_init = \
@@ -784,8 +791,7 @@ def _push_data(ds, target, content, data, force, jobs, res_kwargs,
                 message='Slated for transport, but no content present',
             )
 
-    cmd = ['git', 'annex', 'copy', '--batch', '-z', '--to', target,
-           '--json', '--json-error-messages', '--json-progress']
+    cmd = ['copy', '--batch', '-z', '--to', target]
 
     if jobs:
         cmd.extend(['--jobs', str(jobs)])
@@ -839,26 +845,15 @@ def _push_data(ds, target, content, data, force, jobs, res_kwargs,
         # rewind stdin buffer
         file_list.seek(0)
 
-        # tailor the progress protocol with the total number of files
-        # to be transferred
-        class TailoredPushAnnexJsonProtocol(AnnexJsonProtocol):
-            total_nbytes = nbytes
-
         # and go
-        # TODO try-except and yield what was captured before the crash
-        #res = GitWitlessRunner(
-        res = GitWitlessRunner(
-            cwd=ds.path,
-        ).run(
+        res = ds_repo._call_annex_records(
             cmd,
-            # TODO report how many in total, and give global progress too
-            protocol=TailoredPushAnnexJsonProtocol,
-            stdin=file_list)
-        for c in ('stdout', 'stderr'):
-            if res[c]:
-                lgr.debug('Received unexpected %s from `annex copy`: %s',
-                          c, res[c])
-        for j in res['stdout_json']:
+            stdin=file_list,
+            progress=True,
+            # tailor the progress protocol with the total number of files
+            # to be transferred
+            total_nbytes=nbytes)
+        for j in res:
             yield annexjson2result(j, ds, type='file', **res_kwargs)
 
     for annex_key, paths in repkey_paths.items():
