@@ -17,9 +17,9 @@ import os.path as op
 from collections import OrderedDict
 
 from datalad.utils import (
-    assure_list,
-    assure_unicode,
     bytes2human,
+    ensure_list,
+    ensure_unicode,
     get_dataset_root,
 )
 from datalad.interface.base import (
@@ -327,7 +327,7 @@ class Status(Interface):
         paths_by_ds = OrderedDict()
         if path:
             # sort any path argument into the respective subdatasets
-            for p in sorted(map(assure_unicode, assure_list(path))):
+            for p in sorted(map(ensure_unicode, ensure_list(path))):
                 # it is important to capture the exact form of the
                 # given path argument, before any normalization happens
                 # for further decision logic below
