@@ -42,7 +42,7 @@ def test_basics(src, dst):
     clone.config.set(
         'datalad.result-hook.alwaysbids.call-json',
         # string substitutions based on the result record are supported
-        'run_procedure {{"dataset":"{path}","spec":"cfg_metadatatypes bids"}}',
+        'run_procedure {{"dataset":"{path}","spec":"cfg_metadatatypes bids dicom"}}',
         where='local',
     )
     # config on which kind of results this hook should operate
@@ -93,11 +93,13 @@ def test_basics(src, dst):
     # setup done, now see if it works
     clone.get('subds')
     clone_sub = Dataset(clone.pathobj / 'subds')
-    eq_(clone_sub.config.get('datalad.metadata.nativetype'), 'bids')
+    eq_(clone_sub.config.get('datalad.metadata.nativetype', get_all=True),
+        ('bids', 'dicom'))
     # now the same thing with a result_xfm, should make no difference
     clone.get('subds2')
     clone_sub2 = Dataset(clone.pathobj / 'subds2')
-    eq_(clone_sub2.config.get('datalad.metadata.nativetype'), 'bids')
+    eq_(clone_sub2.config.get('datalad.metadata.nativetype', get_all=True),
+        ('bids', 'dicom'))
 
     # hook auto-unlocks the file
     if not clone.repo.is_managed_branch():
