@@ -12,7 +12,7 @@ import os
 import os.path as op
 
 from datalad.utils import (
-    assure_list,
+    ensure_list,
     Path,
     on_windows,
     rmtree,
@@ -29,8 +29,10 @@ from datalad.tests.utils import (
     create_tree,
     DEFAULT_BRANCH,
     eq_,
+    known_failure,
     known_failure_appveyor,
     known_failure_windows,
+    maybe_adjust_repo,
     OBSCURE_FILENAME,
     ok_,
     SkipTest,
@@ -221,21 +223,25 @@ def test_subsuperdataset_save(path):
     sub2 = parent.create(sub1.pathobj / 'sub2')
     sub3 = parent.create(sub2.pathobj / 'sub3')
     assert_repo_status(path)
-    # now we will lobotomize that sub2 so git would fail if any query is performed.
-    rmtree(str(sub3.pathobj / '.git' / 'objects'))
+    # now we will lobotomize that sub3 so git would fail if any query is performed.
+    (sub3.pathobj / '.git' / 'config').chmod(0o000)
+    try:
+        sub3.repo.call_git(['ls-files'], read_only=True)
+        raise SkipTest
+    except CommandError:
+        # desired outcome
+        pass
     # the call should proceed fine since neither should care about sub3
     # default is no recursion
     parent.save('sub1')
     sub1.save('sub2')
     assert_raises(CommandError, parent.save, 'sub1', recursive=True)
-    # and should fail if we request saving while in the parent directory
-    # but while not providing a dataset, since operation would run within
-    # pointed subdataset
-    with chpwd(sub1.path):
-        assert_raises(CommandError, save, 'sub2')
-    # but should not fail in the top level superdataset
+    # and should not fail in the top level superdataset
     with chpwd(parent.path):
         save('sub1')
+    # or in a subdataset above the problematic one
+    with chpwd(sub1.path):
+        save('sub2')
 
 
 @skip_wo_symlink_capability
@@ -398,10 +404,10 @@ def test_add_files(path):
             status = ds.repo.annexstatus(['dir'])
         else:
             result = ds.save(arg[0], to_git=arg[1])
-            for a in assure_list(arg[0]):
+            for a in ensure_list(arg[0]):
                 assert_result_count(result, 1, path=str(ds.pathobj / a))
             status = ds.repo.get_content_annexinfo(
-                ut.Path(p) for p in assure_list(arg[0]))
+                ut.Path(p) for p in ensure_list(arg[0]))
         for f, p in status.items():
             if arg[1]:
                 assert p.get('key', None) is None, f
@@ -570,7 +576,7 @@ def test_add_recursive(path):
 
     # recursive add should not even touch sub1, because
     # it knows that it is clean
-    res = parent.save(recursive=True)
+    res = parent.save(recursive=True, jobs=5)
     # the key action is done
     assert_result_count(
         res, 1, path=op.join(subsub.path, 'new'), action='add', status='ok')
@@ -845,3 +851,28 @@ def test_save_nested_subs_explicit_paths(path):
     ds.save(path=spaths)
     eq_(set(ds.subdatasets(recursive=True, result_xfm="relpaths")),
         set(map(str, spaths)))
+
+
+@with_tempfile
+def test_save_gitrepo_annex_subds_adjusted(path):
+    ds = Dataset(path).create(annex=False)
+    subds = ds.create("sub")
+    maybe_adjust_repo(subds.repo)
+    (subds.pathobj / "foo").write_text("foo")
+    subds.save()
+    ds.save()
+    assert_repo_status(ds.path)
+
+
+@known_failure
+@with_tempfile
+def test_save_adjusted_partial(path):
+    ds = Dataset(path).create()
+    subds = ds.create("sub")
+    maybe_adjust_repo(subds.repo)
+    (subds.pathobj / "foo").write_text("foo")
+    subds.save()
+    (ds.pathobj / "other").write_text("staged, not for committing")
+    ds.repo.call_git(["add", "other"])
+    ds.save(path=["sub"])
+    assert_repo_status(ds.path, added=["other"])
