@@ -28,7 +28,7 @@ from ..support.locking import lock_if_check_fails
 from ..support.path import exists
 from ..utils import getpwd
 from ..utils import unique
-from ..utils import assure_bytes
+from ..utils import ensure_bytes
 from ..utils import unlink
 from .base import AnnexCustomRemote
 from .main import main as super_main
@@ -153,7 +153,10 @@ class ArchiveAnnexCustomRemote(AnnexCustomRemote):
         Made "generators all the way" as an exercise but also to delay any
         checks etc until really necessary.
         """
-        urls = self.get_URLS(key)
+        # we will need all URLs anyways later on ATM, so lets list() them
+        # Anyways here we have a single scheme (archive) so there is not
+        # much optimization possible
+        urls = list(self.gen_URLS(key))
 
         akey_afiles = [
             self._parse_url(url)[:2]  # skip size
@@ -255,9 +258,8 @@ class ArchiveAnnexCustomRemote(AnnexCustomRemote):
             # Extract via cache only if size is not yet known
             if size is None:
                 # if for testing we want to force getting the archive extracted
-                # _ = self.cache.assure_extracted(self._get_key_path(akey)) # TEMP
                 efile = self.cache[akey_path].get_extracted_filename(afile)
-                efile = assure_bytes(efile)
+                efile = ensure_bytes(efile)
 
                 if exists(efile):
                     size = os.stat(efile).st_size
@@ -414,6 +416,8 @@ class ArchiveAnnexCustomRemote(AnnexCustomRemote):
         # TODO: we need to report user somehow about this happening and
         # progress on the download
         from humanize import naturalsize
+        from datalad.support.annexrepo import AnnexJsonProtocol
+
         akey_size = self.repo.get_size_from_key(akey)
         self.info(
             "To obtain some keys we need to fetch an archive "
@@ -421,18 +425,10 @@ class ArchiveAnnexCustomRemote(AnnexCustomRemote):
             % (naturalsize(akey_size) if akey_size else "unknown")
         )
 
-        def progress_indicators(l):
-            self.info("PROGRESS-JSON: " + l.rstrip(os.linesep))
-
-        self.runner(["git", "annex", "get",
-                     "--json", "--json-progress",
-                     "--key", akey
-                     ],
-                    log_stdout=progress_indicators,
-                    log_stderr='offline',
-                    # False, # to avoid lock down
-                    log_online=True,
-                    cwd=self.path, expect_stderr=True)
+        self.repo._call_annex(
+            ["get", "--json", "--json-progress", "--key", akey],
+            protocol=AnnexJsonProtocol,
+        )
 
 
 def main():
