@@ -84,6 +84,10 @@ class RIARemoteError(RemoteError):
 
 class IOBase(object):
     """Abstract class with the desired API for local/remote operations"""
+
+    def get_7z(self):
+        raise NotImplementedError
+
     def mkdir(self, path):
         raise NotImplementedError
 
@@ -207,16 +211,19 @@ class LocalIO(IOBase):
             # no archive, not file
             return False
         loc = str(file_path)
-        from datalad.cmd import Runner
-        runner = Runner()
+        from datalad.cmd import (
+            StdOutErrCapture,
+            WitlessRunner,
+        )
+        runner = WitlessRunner()
         # query 7z for the specific object location, keeps the output
         # lean, even for big archives
-        out, err = runner(
+        out = runner.run(
             ['7z', 'l', str(archive_path),
              loc],
-            log_stdout=True,
+            protocol=StdOutErrCapture,
         )
-        return loc in out
+        return loc in out['stdout']
 
     def read_file(self, file_path):
 
@@ -230,6 +237,32 @@ class LocalIO(IOBase):
         with open(str(file_path), mode) as f:
             f.write(content)
 
+    def get_7z(self):
+        from datalad.cmd import CommandError, StdOutErrCapture, WitlessRunner
+        # from datalad.utils import on_windows
+
+        runner = WitlessRunner()
+        # TODO: To not rely on availability in PATH we might want to use `which`
+        #       (`where` on windows) and get the actual path to 7z to re-use in
+        #       in_archive() and get().
+        #       Note: `command -v XXX` or `type` might be cross-platform
+        #       solution!
+        #       However, for availability probing only, it would be sufficient
+        #       to just call 7z and see whether it returns zero.
+
+        # cmd = 'where' if on_windows else 'which'
+        # try:
+        #     out = runner.run([cmd, '7z'], protocol=StdOutErrCapture)
+        #     return out['stdout']
+        # except CommandError:
+        #     return None
+
+        try:
+            runner.run('7z', protocol=StdOutErrCapture)
+            return True
+        except (FileNotFoundError, CommandError):
+            return False
+
 
 class SSHRemoteIO(IOBase):
     """IO operation if the object tree is SSH-accessible
@@ -519,6 +552,28 @@ class SSHRemoteIO(IOBase):
             raise RIARemoteError("Could not write to {}".format(str(file_path)))
 
 
+    def get_7z(self):
+        # TODO: To not rely on availability in PATH we might want to use `which`
+        #       (`where` on windows) and get the actual path to 7z to re-use in
+        #       in_archive() and get().
+        #       Note: `command -v XXX` or `type` might be cross-platform
+        #       solution!
+        #       However, for availability probing only, it would be sufficient
+        #       to just call 7z and see whether it returns zero.
+
+        try:
+            self._run("7z", check=True, no_output=False)
+            return True
+        except RemoteCommandFailedError:
+            return False
+
+        # try:
+        #     out = self._run("which 7z", check=True, no_output=False)
+        #     return out
+        # except RemoteCommandFailedError:
+        #     return None
+
+
 class HTTPRemoteIO(object):
     # !!!!
     # This is not actually an IO class like SSHRemoteIO and LocalIO and needs
@@ -556,15 +611,8 @@ class HTTPRemoteIO(object):
         # to annexremote.dirhash from within IO classes
 
         url = self.base_url + "/annex/objects/" + str(key_path)
-        response = requests.get(url, stream=True)
-
-        with open(filename, 'wb') as dst_file:
-            bytes_received = 0
-            for chunk in response.iter_content(chunk_size=self.buffer_size,
-                                               decode_unicode=False):
-                dst_file.write(chunk)
-                bytes_received += len(chunk)
-                progress_cb(bytes_received)
+        from datalad.support.network import download_url
+        download_url(url, filename, overwrite=True)
 
 
 def handle_errors(func):
@@ -579,7 +627,7 @@ def handle_errors(func):
     # TODO: configurable on remote end (flag within layout_version!)
 
     @wraps(func)
-    def new_func(self, *args, **kwargs):
+    def  _wrap_handle_errors(self, *args, **kwargs):
         try:
             return func(self, *args, **kwargs)
         except Exception as e:
@@ -590,16 +638,32 @@ def handle_errors(func):
                 entry = "{time}: Error:\n{exc_str}\n" \
                         "".format(time=datetime.now(),
                                   exc_str=exc_str)
-                log_target = self.store_base_path / 'error_logs' / \
+                # ensure base path is platform path
+                log_target = Path(self.store_base_path) / 'error_logs' / \
                              "{dsid}.{uuid}.log".format(dsid=self.archive_id,
                                                         uuid=self.uuid)
                 self.io.write_file(log_target, entry, mode='a')
+
+            try:
+                # We're done using io, so let it perform any needed cleanup. At
+                # the moment, this is only relevant for SSHRemoteIO, in which
+                # case it cleans up the SSH socket and prevents a hang with
+                # git-annex 8.20201103 and later.
+                self.io.close()
+            except AttributeError:
+                pass
+            else:
+                # Note: It is documented as safe to unregister a function even
+                # if it hasn't been registered.
+                from atexit import unregister
+                unregister(self.io.close)
+
             if not isinstance(e, RIARemoteError):
                 raise RIARemoteError(str(e))
             else:
                 raise e
 
-    return new_func
+    return  _wrap_handle_errors
 
 
 class NoLayoutVersion(Exception):
@@ -622,10 +686,12 @@ class RIARemote(SpecialRemote):
         if hasattr(self, 'configs'):
             # introduced in annexremote 1.4.2 to support LISTCONFIGS
             self.configs['url'] = "RIA store to use"
+            self.configs['archive-id'] = "Dataset ID. Should be set " \
+                                         "automatically by datalad"
         # machine to SSH-log-in to access/store the data
         # subclass must set this
         self.storage_host = None
-        # must be absolute, and POSIX
+        # must be absolute, and POSIX (will be instance of PurePosixPath)
         # subclass must set this
         self.store_base_path = None
         # by default we can read and write
@@ -656,8 +722,9 @@ class RIARemote(SpecialRemote):
         isn't configured, sets the remote to read-only operation.
         """
 
+        # ensure base path is platform path
         dataset_tree_version_file = \
-            self.store_base_path / 'ria-layout-version'
+            Path(self.store_base_path) / 'ria-layout-version'
 
         # check dataset tree version
         try:
@@ -764,6 +831,8 @@ class RIARemote(SpecialRemote):
     def _verify_config(self, gitdir, fail_noid=True):
         # try loading all needed info from (git) config
         name = self.annex.getconfig('name')
+        if not name:
+            name = self.annex.getconfig('sameas-name')
         if not name:
             raise RIARemoteError(
                 "Cannot determine special remote name, got: {}".format(
@@ -794,7 +863,8 @@ class RIARemote(SpecialRemote):
                     "No remote base path configured. "
                     "Specify `base-path` setting.")
 
-        self.store_base_path = Path(self.store_base_path)
+        # the base path is ultimately derived from a URL, always treat as POSIX
+        self.store_base_path = PurePosixPath(self.store_base_path)
         if not self.store_base_path.is_absolute():
             raise RIARemoteError(
                 'Non-absolute object tree base path configuration: %s'
@@ -846,10 +916,14 @@ class RIARemote(SpecialRemote):
         locations, etc.
         If this doesn't raise, the remote end should be fine to work with.
         """
+        # make sure the base path is a platform path when doing local IO
+        # the incoming Path object is a PurePosixPath
+        store_base_path = Path(self.store_base_path) \
+            if self._local_io else self.store_base_path
 
         # cache remote layout directories
         self.remote_git_dir, self.remote_archive_dir, self.remote_obj_dir = \
-            self.get_layout_locations(self.store_base_path, self.archive_id)
+            self.get_layout_locations(store_base_path, self.archive_id)
 
         read_only_msg = "Treating remote as read-only in order to" \
                         "prevent damage by putting things into an unknown " \
@@ -865,7 +939,7 @@ class RIARemote(SpecialRemote):
                                      self.known_versions_dst)
             self._set_read_only(reason + read_only_msg)
         except NoLayoutVersion:
-            reason = "Remote doesn't report any dataset tree version." \
+            reason = "Remote doesn't report any dataset tree version. " \
                      "Consider upgrading datalad or add a fitting " \
                      "'ria-layout-version' file at the RIA store's " \
                      "root."
@@ -882,7 +956,7 @@ class RIARemote(SpecialRemote):
                                self.known_versions_objt)
             self._set_read_only(reason + read_only_msg)
         except NoLayoutVersion:
-            reason = "Remote doesn't report any object tree version." \
+            reason = "Remote doesn't report any object tree version. " \
                      "Consider upgrading datalad or add a fitting " \
                      "'ria-layout-version' file at the remote " \
                      "dataset root. "
@@ -979,12 +1053,14 @@ class RIARemote(SpecialRemote):
         if not isinstance(self.io, HTTPRemoteIO):
             self.get_store()
 
-        # report active special remote configuration
+        # report active special remote configuration/status
         self.info = {
             'store_base_path': str(self.store_base_path),
             'storage_host': 'local'
             if self._local_io() else self.storage_host,
         }
+        if not isinstance(self.io, HTTPRemoteIO):
+            self.info['7z'] = ("not " if not self.io.get_7z() else "") + "available"
 
     @handle_errors
     def transfer_store(self, key, filename):
