@@ -30,7 +30,8 @@ from datalad.ui import ui
 
 from datalad.cmd import (
     CommandError,
-    Runner,
+    StdOutErrCapture,
+    WitlessRunner,
 )
 from datalad.consts import (
     TIMESTAMP_FMT,
@@ -49,7 +50,6 @@ from datalad.distribution.dataset import (
     resolve_path,
     require_dataset,
 )
-from datalad.interface.annotate_paths import AnnotatePaths
 from datalad.interface.base import (
     build_doc,
     Interface,
@@ -89,9 +89,9 @@ from datalad.utils import (
     make_tempfile,
     _path_,
     slash_join,
-    assure_list,
-    quote_cmdlinearg,
+    ensure_list,
 )
+from datalad.core.local.diff import diff_dataset
 
 from datalad.utils import on_windows
 
@@ -101,9 +101,13 @@ lgr = logging.getLogger('datalad.distribution.create_sibling')
 mkdir_cmd = "mkdir" if on_windows else "mkdir -p" 
 
 
-class _RunnerAdapter(Runner):
+class _RunnerAdapter(WitlessRunner):
     """An adapter to use interchanegably with SSH connection"""
 
+    def __call__(self, cmd):
+        out = self.run(cmd, protocol=StdOutErrCapture)
+        return out['stdout'], out['stderr']
+
     def get_git_version(self):
         return external_versions['cmd:git']
 
@@ -115,7 +119,7 @@ class _RunnerAdapter(Runner):
         import shutil
         copy_fn = shutil.copy2 if preserve_attrs else shutil.copy
         if recursive:
-            args = source, destination
+            args = [source, destination]
             kwargs = {"copy_function": copy_fn}
             try:
                 shutil.copytree(*args, **kwargs)
@@ -127,7 +131,7 @@ class _RunnerAdapter(Runner):
                 cmd = ["cp", "-R"]
                 if preserve_attrs:
                     cmd.append("-p")
-                self(cmd + [quote_cmdlinearg(a) for a in args])
+                self(cmd + args)
         else:
             copy_fn(source, destination)
 
@@ -648,51 +652,69 @@ class CreateSibling(Interface):
         # parse the base dataset to find all subdatasets that need processing
         #
         to_process = []
-        for ap in AnnotatePaths.__call__(
-                dataset=refds_path,
-                # only a single path!
-                path=refds_path,
-                recursive=recursive,
-                recursion_limit=recursion_limit,
+        cand_ds = [
+            Dataset(r['path'])
+            for r in diff_dataset(
+                ds,
+                fr=since,
+                to=None,
+                # make explicit, but doesn't matter, no recursion in diff()
+                constant_refs=True,
+                # contrain to the paths of all locally existing subdatasets
+                path=[
+                    sds['path']
+                    for sds in ds.subdatasets(
+                        recursive=recursive,
+                        recursion_limit=recursion_limit,
+                        fulfilled=True,
+                        result_renderer=None)
+                ],
+                # save cycles, we are only looking for datasets
+                annex=None,
+                untracked='no',
+                # recursion was done faster by subdatasets()
+                recursive=False,
+                # save cycles, we are only looking for datasets
+                eval_file_type=False,
+            )
+            if r.get('type') == 'dataset' and r.get('state', None) != 'clean'
+        ]
+        # check remotes setup
+        for d in cand_ds if since else ([ds] + cand_ds):
+            d_repo = d.repo
+            if d_repo is None:
+                continue
+            checkds_remotes = d.repo.get_remotes()
+            res = dict(
                 action='create_sibling',
-                # both next should not happen anyways
-                unavailable_path_status='impossible',
-                nondataset_path_status='error',
-                modified=since,
-                return_type='generator',
-                on_failure='ignore'):
-            if ap.get('status', None):
-                # this is done
-                yield ap
-                continue
-            if ap.get('type', None) != 'dataset' or ap.get('state', None) == 'absent':
-                # this can happen when there is `since`, but we have no
-                # use for anything but datasets here
-                continue
-            checkds_remotes = Dataset(ap['path']).repo.get_remotes() \
-                if ap.get('state', None) != 'absent' \
-                else []
+                path=d.path,
+                type='dataset',
+            )
+
             if publish_depends:
                 # make sure dependencies are valid
                 # TODO: inherit -- we might want to automagically create
                 # those dependents as well???
-                unknown_deps = set(assure_list(publish_depends)).difference(checkds_remotes)
+                unknown_deps = set(ensure_list(publish_depends)).difference(
+                    checkds_remotes)
                 if unknown_deps:
-                    ap['status'] = 'error'
-                    ap['message'] = (
-                        'unknown sibling(s) specified as publication dependency: %s',
-                        unknown_deps)
-                    yield ap
+                    yield dict(
+                        res,
+                        status='error',
+                        message=('unknown sibling(s) specified as publication '
+                                 'dependency: %s', unknown_deps),
+                    )
                     continue
             if name in checkds_remotes and existing in ('error', 'skip'):
-                ap['status'] = 'error' if existing == 'error' else 'notneeded'
-                ap['message'] = (
-                    "sibling '%s' already configured (specify alternative name, or force "
-                    "reconfiguration via --existing",
-                    name)
-                yield ap
+                yield dict(
+                    res,
+                    status='error' if existing == 'error' else 'notneeded',
+                    message=(
+                        "sibling '%s' already configured (specify alternative "
+                        "name, or force reconfiguration via --existing", name),
+                )
                 continue
-            to_process.append(ap)
+            to_process.append(res)
 
         if not to_process:
             # we ruled out all possibilities
@@ -1017,7 +1039,7 @@ done
             mode = shared
 
         if mode:
-            ssh('chmod {} -R {} {}'.format(
+            ssh('chmod -R {} {} {}'.format(
                 mode,
                 sh_quote(dirname(webresources_remote)),
                 sh_quote(opj(path, 'index.html'))))
