@@ -48,7 +48,7 @@ from datalad.utils import (
     get_dataset_root as rev_get_dataset_root,
     Path,
     PurePath,
-    assure_list,
+    ensure_list,
     quote_cmdlinearg,
 )
 
@@ -85,14 +85,19 @@ class Dataset(object, metaclass=PathBasedFlyweight):
     def _flyweight_preproc_path(cls, path):
         """Custom handling for few special abbreviations for datasets"""
         path_ = path
-        if path == '^':
-            # get the topmost dataset from current location. Note that 'zsh'
-            # might have its ideas on what to do with ^, so better use as -d^
-            path_ = Dataset(get_dataset_root(curdir)).get_superdataset(
-                topmost=True).path
-        elif path == '^.':
-            # get the dataset containing current directory
-            path_ = get_dataset_root(curdir)
+        if path in ('^', '^.'):
+            dsroot = get_dataset_root(curdir)
+            if dsroot is None:
+                raise NoDatasetFound('No dataset contains path: {}'.format(
+                    str(Path.cwd())))
+            if path == '^':
+                # get the topmost dataset from current location. Note that 'zsh'
+                # might have its ideas on what to do with ^, so better use as -d^
+                path_ = Dataset(dsroot).get_superdataset(
+                    topmost=True).path
+            elif path == '^.':
+                # the dataset containing current directory
+                path_ = dsroot
         elif path == '///':
             # TODO: logic/UI on installing a default dataset could move here
             # from search?
@@ -342,7 +347,7 @@ class Dataset(object, metaclass=PathBasedFlyweight):
             # However, if this was the case before as well, we don't want a new
             # instance of ConfigManager
             if self._cfg_bound in (True, None):
-                self._cfg = ConfigManager(dataset=None, dataset_only=False)
+                self._cfg = ConfigManager(dataset=None)
                 self._cfg_bound = False
 
         else:
@@ -583,7 +588,7 @@ def require_dataset(dataset, check_installed=True, purpose=None):
 # New helpers, courtesy of datalad-revolution.
 
 
-def resolve_path(path, ds=None):
+def resolve_path(path, ds=None, ds_resolved=None):
     """Resolve a path specification (against a Dataset location)
 
     Any path is returned as an absolute path. If, and only if, a dataset
@@ -604,8 +609,11 @@ def resolve_path(path, ds=None):
     path : str or PathLike or list
       Platform-specific path specific path specification. Multiple path
       specifications can be given as a list
-    ds : Dataset or None
+    ds : Dataset or PathLike or None
       Dataset instance to resolve relative paths against.
+    ds_resolved : Dataset or None
+      A dataset instance that was created from `ds` outside can be provided
+      to avoid multiple instantiation on repeated calls.
 
     Returns
     -------
@@ -615,10 +623,10 @@ def resolve_path(path, ds=None):
     """
     got_ds_instance = isinstance(ds, Dataset)
     if ds is not None and not got_ds_instance:
-        ds = require_dataset(
+        ds = ds_resolved or require_dataset(
             ds, check_installed=False, purpose='path resolution')
     out = []
-    for p in assure_list(path):
+    for p in ensure_list(path):
         if ds is None or not got_ds_instance:
             # no dataset at all or no instance provided -> CWD is always the reference
             # nothing needs to be done here. Path-conversion and absolutification
