@@ -64,7 +64,7 @@ from datalad.distribution.dataset import (
 )
 from datalad.distribution.update import Update
 from datalad.utils import (
-    assure_list,
+    ensure_list,
     slash_join,
     Path,
 )
@@ -445,7 +445,7 @@ def _configure_remote(
 
         if publish_depends:
             # Check if all `deps` remotes are known to the `repo`
-            unknown_deps = set(assure_list(publish_depends)).difference(
+            unknown_deps = set(ensure_list(publish_depends)).difference(
                 known_remotes)
             if unknown_deps:
                 result_props['status'] = 'error'
@@ -511,7 +511,7 @@ def _configure_remote(
                 # config vars are incremental, so make sure we start from
                 # scratch
                 ds.config.unset(depvar, where='local', reload=False)
-            for d in assure_list(publish_depends):
+            for d in ensure_list(publish_depends):
                 lgr.info(
                     'Configure additional publication dependency on "%s"',
                     d)
@@ -521,7 +521,7 @@ def _configure_remote(
         if publish_by_default:
             if dfltvar in ds.config:
                 ds.config.unset(dfltvar, where='local', reload=False)
-            for refspec in assure_list(publish_by_default):
+            for refspec in ensure_list(publish_by_default):
                 lgr.info(
                     'Configure additional default publication refspec "%s"',
                     refspec)
@@ -564,13 +564,12 @@ def _configure_remote(
                     # XXX except it is not enough
 
                     # make special remote of type=git (see #335)
-                    ds.repo._run_annex_command(
+                    ds.repo.call_annex([
                         'initremote',
-                        annex_options=[
-                            as_common_datasrc,
-                            'type=git',
-                            'location={}'.format(url),
-                            'autoenable=true'])
+                        as_common_datasrc,
+                        'type=git',
+                        'location={}'.format(url),
+                        'autoenable=true'])
                 else:
                     yield dict(
                         status='impossible',
@@ -596,7 +595,7 @@ def _configure_remote(
             result_props['message'] = 'cannot set description of a plain Git repository'
             yield result_props
             return
-        ds.repo._run_annex_command('describe', annex_options=[name, description])
+        ds.repo.call_annex(['describe', name, description])
 
     # report all we know at once
     info = list(_query_remotes(ds, name, known_remotes, get_annex_info=get_annex_info))[0]
