@@ -12,24 +12,27 @@
 from glob import glob
 from os.path import join as opj
 
-from datalad.tests.utils import with_tempfile
-from datalad.tests.utils import assert_raises
-from datalad.tests.utils import ok_
-from datalad.tests.utils import ok_clean_git
-from datalad.tests.utils import known_failure_githubci_win
-from datalad.utils import swallow_logs
-from datalad.utils import swallow_outputs
-from datalad.utils import chpwd
-from datalad.support.gitrepo import GitRepo
+from datalad.core.local.repo import repo_from_path
+from datalad.tests.utils import (
+    with_tempfile,
+    assert_raises,
+    assert_repo_status,
+    ok_,
+)
+from datalad.utils import (
+    swallow_logs,
+    swallow_outputs,
+    chpwd,
+)
 from datalad.distribution.create_test_dataset import _parse_spec
 
-from nose.tools import eq_
+from datalad.tests.utils import eq_
 
 
 @with_tempfile(mkdir=True)
 def test_create(outdir):
     from datalad.api import create
-    assert_raises(ValueError, create, outdir, description='Precious data', no_annex=True)
+    assert_raises(ValueError, create, outdir, description='Precious data', annex=False)
 
 
 def test_parse_spec():
@@ -45,7 +48,7 @@ def test_create_test_dataset():
         dss = create_test_dataset(spec='2/1-2')
     ok_(5 <= len(dss) <= 7)  # at least five - 1 top, two on top level, 1 in each
     for ds in dss:
-        ok_clean_git(ds, annex=None)  # some of them are annex but we just don't check
+        assert_repo_status(ds, annex=None)  # some of them are annex but we just don't check
         ok_(len(glob(opj(ds, 'file*'))))
 
 
@@ -55,7 +58,7 @@ def test_create_1test_dataset():
     with swallow_outputs():
         dss = create_test_dataset()
     eq_(len(dss), 1)
-    ok_clean_git(dss[0], annex=False)
+    assert_repo_status(dss[0], annex=False)
 
 
 @with_tempfile(mkdir=True)
@@ -66,10 +69,9 @@ def test_new_relpath(topdir):
     eq_(dss[0], opj(topdir, 'testds'))
     eq_(len(dss), 2)  # 1 top + 1 sub-dataset as demanded
     for ds in dss:
-        ok_clean_git(ds, annex=False)
+        assert_repo_status(ds, annex=False)
 
 
-@known_failure_githubci_win
 @with_tempfile()
 def test_hierarchy(topdir):
     # GH 1178
@@ -80,8 +82,9 @@ def test_hierarchy(topdir):
     eq_(len(dss), 3)
     eq_(dss[0], topdir)
     for ids, ds in enumerate(dss):
-        ok_clean_git(ds, annex=False)
+        assert_repo_status(ds, annex=False)
         # each one should have 2 commits (but the last one)-- one for file and
         # another one for sub-dataset
-        repo = GitRepo(ds)
-        eq_(len(list(repo.get_branch_commits())), 1 + int(ids<2))
+        repo = repo_from_path(ds)
+        if not hasattr(repo, 'is_managed_branch') or not repo.is_managed_branch():
+            eq_(len(list(repo.get_branch_commits_())), 1 + int(ids < 2))
