@@ -45,12 +45,17 @@ from datalad.tests.utils import (
     assert_result_count,
     assert_message,
     serve_path_via_http,
+    skip_if_adjusted_branch,
+    skip_ssh,
+    skip_if_on_windows,
     slow,
     known_failure_windows,
+    known_failure_githubci_win,
 )
 from datalad.utils import (
     with_pathsep,
     chpwd,
+    Path,
     rmtree,
 )
 from ..dataset import Dataset
@@ -70,6 +75,8 @@ def _make_dataset_hierarchy(path):
     return origin, origin_sub1, origin_sub2, origin_sub3, origin_sub4
 
 
+# AssertionError since does get extra record {'cost': 400, 'name': 'bang', 'url': 'youredead', 'from_config': True},
+@known_failure_githubci_win
 @with_tempfile
 @with_tempfile
 @with_tempfile
@@ -634,3 +641,57 @@ def test_gh3356(src, path):
     assert_result_count(
         clone.status(recursive=True, annex='all', report_filetype='eval'), 2,
         action='status', has_content=True)
+
+
+# The setup here probably breaks down with adjusted branches.
+@skip_if_adjusted_branch
+@slow  # ~12s
+@skip_if_on_windows
+@skip_ssh
+@with_tempfile(mkdir=True)
+def test_get_subdataset_direct_fetch(path):
+    path = Path(path)
+    origin = Dataset(path / "origin").create()
+    for sub in ["s0", "s1"]:
+        sds = origin.create(origin.pathobj / sub)
+        sds.repo.commit(msg="another commit", options=["--allow-empty"])
+    origin.save()
+    s0 = Dataset(origin.pathobj / "s0")
+    s1 = Dataset(origin.pathobj / "s1")
+    # Abandon the recorded commit so that it needs to be brought down by a
+    # direct fetch.
+    s0.repo.call_git(["reset", "--hard", "HEAD~"])
+    s1.repo.call_git(["reset", "--hard", "HEAD~"])
+
+    # Tweak the configuration of s0 to make the direct fetch fail.
+    # Disallow direct oid fetch (default).
+    s0.repo.config.set("uploadpack.allowAnySHA1InWant", "false",
+                       where="local")
+    # Configure the fetcher to avoid v2, which allows fetching unadvertised
+    # objects regardless of the value of uploadpack.allowAnySHA1InWant.
+    s0.repo.config.set("protocol.version", "0", where="local")
+
+    # Configure s1 to succeed with direct fetch.
+    s1.repo.config.set("uploadpack.allowAnySHA1InWant", "true",
+                       where="local")
+
+    clone = install(
+        str(path / "clone"),
+        source="ssh://datalad-test:" + origin.repo.pathobj.as_posix())
+
+    res = clone.get(["s0", "s1"], on_failure="ignore")
+    assert_result_count(res, 1,
+                        action="install", type="dataset", status="error")
+    assert_result_count(res, 1,
+                        action="install", type="dataset", status="ok")
+
+
+@with_tempfile()
+def test_get_relays_command_errors(path):
+    ds = Dataset(path).create()
+    (ds.pathobj / "foo").write_text("foo")
+    ds.save()
+    ds.drop("foo", check=False)
+    assert_result_count(
+        ds.get("foo", on_failure="ignore", result_renderer=None),
+        1, action="get", type="file", status="error")
