@@ -10,42 +10,49 @@
 """
 
 import os
-from os.path import join as opj, split as psplit
-from os.path import exists, lexists
-from os.path import realpath
-from os.path import isdir
+from os.path import (
+    join as opj,
+    split as psplit,
+    exists,
+    lexists,
+    isdir,
+)
 from glob import glob
 
-from datalad.api import uninstall
-from datalad.api import drop
-from datalad.api import remove
-from datalad.api import install
-from datalad.api import create
+from datalad.api import (
+    uninstall,
+    drop,
+    remove,
+    install,
+    create,
+)
 from datalad.support.exceptions import IncompleteResultsError
-from datalad.tests.utils import ok_
-from datalad.tests.utils import eq_
-from datalad.tests.utils import with_testrepos
-from datalad.tests.utils import SkipTest
-from datalad.tests.utils import assert_raises
-from datalad.tests.utils import assert_status
-from datalad.tests.utils import assert_in
-from datalad.tests.utils import assert_result_count
-from datalad.tests.utils import assert_result_values_cond
-from datalad.tests.utils import ok_file_under_git
-from datalad.tests.utils import ok_clean_git
-from datalad.tests.utils import with_tempfile
-from datalad.tests.utils import with_tree
-from datalad.tests.utils import create_tree
-from datalad.tests.utils import skip_if_no_network
-from datalad.tests.utils import use_cassette
-from datalad.tests.utils import usecase
-from datalad.tests.utils import known_failure_githubci_win
-from datalad.tests.utils import known_failure_windows
-from datalad.utils import chpwd
-from datalad.utils import _path_
-from datalad.utils import Path
+from datalad.tests.utils import (
+    ok_,
+    eq_,
+    with_testrepos,
+    SkipTest,
+    assert_raises,
+    assert_status,
+    assert_in,
+    assert_repo_status,
+    assert_result_count,
+    assert_result_values_cond,
+    ok_file_under_git,
+    with_tempfile,
+    with_tree,
+    create_tree,
+    skip_if_no_network,
+    use_cassette,
+    usecase,
+    known_failure_windows,
+)
+from datalad.utils import (
+    chpwd,
+    _path_,
+    Path,
+)
 from datalad.support.external_versions import external_versions
-
 from ..dataset import Dataset
 
 
@@ -83,7 +90,7 @@ def test_clean_subds_removal(path):
     subds1 = ds.create('one')
     subds2 = ds.create('two')
     eq_(sorted(ds.subdatasets(result_xfm='relpaths')), ['one', 'two'])
-    ok_clean_git(ds.path)
+    assert_repo_status(ds.path)
     # now kill one
     res = ds.remove('one', result_xfm=None)
     # subds1 got uninstalled, and ds got the removal of subds1 saved
@@ -91,7 +98,7 @@ def test_clean_subds_removal(path):
     assert_result_count(res, 1, path=subds1.path, action='remove', status='ok')
     assert_result_count(res, 1, path=ds.path, action='save', status='ok')
     ok_(not subds1.is_installed())
-    ok_clean_git(ds.path)
+    assert_repo_status(ds.path)
     # two must remain
     eq_(ds.subdatasets(result_xfm='relpaths'), ['two'])
     # one is gone
@@ -100,12 +107,12 @@ def test_clean_subds_removal(path):
     ds.create('three')
     eq_(sorted(ds.subdatasets(result_xfm='relpaths')), ['three', 'two'])
     ds.uninstall('two')
-    ok_clean_git(ds.path)
+    assert_repo_status(ds.path)
     eq_(sorted(ds.subdatasets(result_xfm='relpaths')), ['three', 'two'])
     ok_(not subds2.is_installed())
     assert(exists(subds2.path))
     res = ds.remove('two', result_xfm='datasets')
-    ok_clean_git(ds.path)
+    assert_repo_status(ds.path)
     # subds2 was already uninstalled, now ds got the removal of subds2 saved
     assert(not exists(subds2.path))
     eq_(ds.subdatasets(result_xfm='relpaths'), ['three'])
@@ -183,8 +190,6 @@ def test_uninstall_git_file(path):
     eq_(res, ['INFO.txt'])
 
 
-# https://github.com/datalad/datalad/pull/3975/checks?check_run_id=369789022#step:8:509
-@known_failure_windows
 @with_testrepos('submodule_annex', flavors=['local'])
 @with_tempfile(mkdir=True)
 def test_uninstall_subdataset(src, dst):
@@ -195,14 +200,17 @@ def test_uninstall_subdataset(src, dst):
     for subds in ds.subdatasets(result_xfm='datasets'):
         ok_(subds.is_installed())
 
-        annexed_files = subds.repo.get_annexed_files()
-        subds.repo.get(annexed_files)
+        repo = subds.repo
+
+        annexed_files = repo.get_content_annexinfo(init=None)
+        repo.get([str(f) for f in annexed_files])
 
         # drop data of subds:
         res = ds.drop(path=subds.path, result_xfm='paths')
-
-        ok_(all([opj(subds.path, f) in res for f in annexed_files]))
-        ok_(all([not i for i in subds.repo.file_has_content(annexed_files)]))
+        ok_(all(str(f) in res for f in annexed_files))
+        ainfo = repo.get_content_annexinfo(paths=annexed_files,
+                                           eval_availability=True)
+        ok_(all(not st["has_content"] for st in ainfo.values()))
         # subdataset is still known
         assert_in(subds.path, ds.subdatasets(result_xfm='paths'))
 
@@ -210,11 +218,6 @@ def test_uninstall_subdataset(src, dst):
 
     for subds in ds.subdatasets(result_xfm='datasets'):
         # uninstall subds itself:
-        if os.environ.get('DATALAD_TESTS_DATALADREMOTE') \
-                and external_versions['git'] < '2.0.9':
-            raise SkipTest(
-                "Known problem with GitPython. See "
-                "https://github.com/gitpython-developers/GitPython/pull/521")
         # simulate a cmdline invocation pointing to the subdataset
         # with a relative path from outside the superdataset to catch
         # https://github.com/datalad/datalad/issues/4001
@@ -233,7 +236,7 @@ def test_uninstall_subdataset(src, dst):
         ok_(exists(subds.path))
 
 
-@known_failure_githubci_win
+@known_failure_windows
 @with_tree({
     'deep': {
         'dir': {
@@ -244,24 +247,24 @@ def test_uninstall_multiple_paths(path):
     ds = Dataset(path).create(force=True)
     subds = ds.create('deep', force=True)
     subds.save(recursive=True)
-    ok_clean_git(subds.path)
+    assert_repo_status(subds.path)
     # needs to be able to add a combination of staged files, modified submodule,
     # and untracked files
     ds.save(recursive=True)
-    ok_clean_git(ds.path)
+    assert_repo_status(ds.path)
     # drop content of all 'kill' files
     topfile = 'kill'
     deepfile = opj('deep', 'dir', 'kill')
     # use a tuple not a list! should also work
     ds.drop((topfile, deepfile), check=False)
-    ok_clean_git(ds.path)
+    assert_repo_status(ds.path)
     files_left = glob(opj(ds.path, '*', '*', '*')) + glob(opj(ds.path, '*'))
     ok_(all([f.endswith('keep') for f in files_left if exists(f) and not isdir(f)]))
     ok_(not ds.repo.file_has_content(topfile))
     ok_(not subds.repo.file_has_content(opj(*psplit(deepfile)[1:])))
     # remove handles for all 'kill' files
     ds.remove([topfile, deepfile], check=False)
-    ok_clean_git(ds.path)
+    assert_repo_status(ds.path)
     files_left = glob(opj(ds.path, '*', '*', '*')) + glob(opj(ds.path, '*'))
     ok_(all([f.endswith('keep') for f in files_left if exists(f) and not isdir(f)]))
     ok_(not any([f.endswith(topfile) for f in files_left]))
@@ -273,12 +276,12 @@ def test_uninstall_dataset(path):
     ok_(not ds.is_installed())
     ds.create()
     ok_(ds.is_installed())
-    ok_clean_git(ds.path)
+    assert_repo_status(ds.path)
     # would only drop data
     ds.drop()
     # actually same as this, for cmdline compat reasons
     ds.drop(path=[])
-    ok_clean_git(ds.path)
+    assert_repo_status(ds.path)
     # removing entire dataset, uninstall will refuse to act on top-level
     # datasets
     assert_raises(IncompleteResultsError, ds.uninstall)
@@ -288,27 +291,27 @@ def test_uninstall_dataset(path):
     ok_(not exists(ds.path))
 
 
-@known_failure_githubci_win
+@known_failure_windows
 @with_tree({'one': 'test', 'two': 'test', 'three': 'test2'})
 def test_remove_file_handle_only(path):
     ds = Dataset(path).create(force=True)
     ds.save()
-    ok_clean_git(ds.path)
+    assert_repo_status(ds.path)
     # make sure there is any key
     ok_(len(ds.repo.get_file_key('one')))
     # both files link to the same key
     eq_(ds.repo.get_file_key('one'),
         ds.repo.get_file_key('two'))
-    rpath_one = realpath(opj(ds.path, 'one'))
-    eq_(rpath_one, realpath(opj(ds.path, 'two')))
-    path_two = opj(ds.path, 'two')
-    ok_(exists(path_two))
+    rpath_one = (ds.pathobj / 'one').resolve()
+    eq_(rpath_one, (ds.pathobj / 'two').resolve())
+    path_two = ds.pathobj / 'two'
+    ok_(path_two.exists())
     # remove one handle, should not affect the other
     ds.remove('two', check=False, message="custom msg")
     eq_(ds.repo.format_commit("%B").rstrip(), "custom msg")
-    eq_(rpath_one, realpath(opj(ds.path, 'one')))
-    ok_(exists(rpath_one))
-    ok_(not exists(path_two))
+    eq_(rpath_one, (ds.pathobj / 'one').resolve())
+    ok_(rpath_one.exists())
+    ok_(not path_two.exists())
     # remove file without specifying the dataset -- shouldn't fail
     with chpwd(path):
         remove('one', check=False)
@@ -318,7 +321,7 @@ def test_remove_file_handle_only(path):
     ok_(ds.repo.dirty)
 
 
-@known_failure_githubci_win
+@known_failure_windows
 @with_tree({'deep': {'dir': {'test': 'testcontent'}}})
 def test_uninstall_recursive(path):
     ds = Dataset(path).create(force=True)
@@ -330,8 +333,8 @@ def test_uninstall_recursive(path):
     assert_result_count(res, 1, action='save', status='ok', type='dataset')
     # save all -> all clean
     ds.save(recursive=True)
-    ok_clean_git(subds.path)
-    ok_clean_git(ds.path)
+    assert_repo_status(subds.path)
+    assert_repo_status(ds.path)
     # now uninstall in subdataset through superdataset
     target_fname = opj('deep', 'dir', 'test')
     # sane starting point
@@ -351,24 +354,24 @@ def test_uninstall_recursive(path):
     lname = opj(ds.path, target_fname)
     ok_(not exists(lname))
     # entire hierarchy saved
-    ok_clean_git(subds.path)
-    ok_clean_git(ds.path)
+    assert_repo_status(subds.path)
+    assert_repo_status(ds.path)
     # now same with actual handle removal
     # content is dropped already, so no checks in place anyway
     ds.remove(target_fname, check=True, recursive=True)
     ok_(not exists(lname) and not lexists(lname))
-    ok_clean_git(subds.path)
-    ok_clean_git(ds.path)
+    assert_repo_status(subds.path)
+    assert_repo_status(ds.path)
 
 
 @with_tempfile()
 def test_remove_dataset_hierarchy(path):
     ds = Dataset(path).create()
     ds.create('deep')
-    ok_clean_git(ds.path)
+    assert_repo_status(ds.path)
     # fail on missing --recursive because subdataset is present
     assert_raises(IncompleteResultsError, ds.remove)
-    ok_clean_git(ds.path)
+    assert_repo_status(ds.path)
     ds.remove(recursive=True)
     # completely gone
     ok_(not ds.is_installed())
@@ -376,7 +379,7 @@ def test_remove_dataset_hierarchy(path):
     # now do it again, but without a reference dataset
     ds = Dataset(path).create()
     ds.create('deep')
-    ok_clean_git(ds.path)
+    assert_repo_status(ds.path)
     remove(dataset=ds.path, recursive=True)
     # completely gone
     ok_(not ds.is_installed())
@@ -390,13 +393,13 @@ def test_careless_subdataset_uninstall(path):
     subds1 = ds.create('deep1')
     ds.create('deep2')
     eq_(sorted(ds.subdatasets(result_xfm='relpaths')), ['deep1', 'deep2'])
-    ok_clean_git(ds.path)
+    assert_repo_status(ds.path)
     # now we kill the sub without the parent knowing
     subds1.uninstall()
     ok_(not subds1.is_installed())
     # mountpoint exists
     ok_(exists(subds1.path))
-    ok_clean_git(ds.path)
+    assert_repo_status(ds.path)
     # parent still knows the sub
     eq_(sorted(ds.subdatasets(result_xfm='relpaths')), ['deep1', 'deep2'])
 
@@ -411,7 +414,7 @@ def test_kill(path):
     ds.save("file.dat")
     subds = ds.create('deep1')
     eq_(sorted(ds.subdatasets(result_xfm='relpaths')), ['deep1'])
-    ok_clean_git(ds.path)
+    assert_repo_status(ds.path)
 
     # and we fail to remove since content can't be dropped
     res = ds.remove(on_failure='ignore')
@@ -442,7 +445,7 @@ def test_remove_recreation(path):
     ds = create(path)
     ds.remove()
     ds = create(path)
-    ok_clean_git(ds.path)
+    assert_repo_status(ds.path)
     ok_(ds.is_installed())
 
 
@@ -493,7 +496,7 @@ def test_failon_nodrop(path):
     sub = ds.create('sub')
     create_tree(sub.path, {'test': 'content'})
     ds.save(opj('sub', 'test'))
-    ok_clean_git(ds.path)
+    assert_repo_status(ds.path)
     eq_(['test'], sub.repo.get_annexed_files(with_content_only=True))
     # we put one file into the dataset's annex, no redundant copies
     # neither uninstall nor remove should work
@@ -512,9 +515,9 @@ def test_uninstall_without_super(path):
     # is just placed underneath the parent, but not an actual subdataset
     parent = Dataset(path).create()
     sub = parent.create('sub')
-    ok_clean_git(parent.path)
+    assert_repo_status(parent.path)
     nosub = create(opj(parent.path, 'nosub'))
-    ok_clean_git(nosub.path)
+    assert_repo_status(nosub.path)
     subreport = parent.subdatasets()
     assert_result_count(subreport, 1, path=sub.path)
     assert_result_count(subreport, 0, path=nosub.path)
@@ -542,7 +545,7 @@ def test_drop_nocrash_absent_subds(path):
     parent = Dataset(path).create()
     sub = parent.create('sub')
     parent.uninstall('sub')
-    ok_clean_git(parent.path)
+    assert_repo_status(parent.path)
     with chpwd(path):
         assert_status('notneeded', drop('.', recursive=True))
 
@@ -551,7 +554,7 @@ def test_drop_nocrash_absent_subds(path):
 def test_remove_more_than_one(path):
     ds = Dataset(path).create(force=True)
     ds.save()
-    ok_clean_git(path)
+    assert_repo_status(path)
     # ensure #1912 stays resolved
     ds.remove(['one', 'two'], check=False)
-    ok_clean_git(path)
+    assert_repo_status(path)
