@@ -36,11 +36,12 @@ from datalad.support.exceptions import InsufficientArgumentsError
 from datalad.support.exceptions import NoDatasetFound
 from datalad.utils import (
     guard_for_format,
+    join_cmdline,
     quote_cmdlinearg,
     split_cmdline,
 )
 
-from datalad.utils import assure_list
+from datalad.utils import ensure_list
 import datalad.support.ansi_colors as ac
 
 from datalad.core.local.run import Run
@@ -77,42 +78,38 @@ def _get_proc_config(name, ds=None):
     """
     # figure what ConfigManager to ask
     cm = cfg if ds is None else ds.config
+    # ConfigManager might return a tuple for different reasons.
+    # The config might have been defined multiple times in the same location
+    # (within .datalad/config for example) or there are multiple values for
+    # it on different levels of git-config (system, user, repo). git-config
+    # in turn does report such things ordered from most general to most
+    # specific configuration. We do want the most specific one here, so
+    # config.get(), which returns the last entry, works here.
+    # TODO: At this point we cannot determine whether it was actually
+    # configured to yield several values by the very same config, in which
+    # case we should actually issue a warning, since we then have no idea
+    # of a priority. But ConfigManager isn't able yet to tell us or to
+    # restrict the possibility to define multiple values to particular items
     v = cm.get('datalad.procedures.{}.call-format'.format(name), None)
     h = cm.get('datalad.procedures.{}.help'.format(name), None)
-    if isinstance(v, tuple):
-        # ConfigManager might return a tuple for different reasons.
-        # The config might have been defined multiple times in the same location
-        # (within .datalad/config for example) or there are multiple values for
-        # it on different levels of git-config (system, user, repo). git-config
-        # in turn does report such things ordered from most general to most
-        # specific configuration. We do want the most specific one here, so we
-        # go with the last entry of that tuple.
-        # TODO: At this point we cannot determine whether it was actually
-        # configured to yield several values by the very same config, in which
-        # case we should actually issue a warning, since we then have no idea
-        # of a priority. But ConfigManager isn't able yet to tell us or to
-        # restrict the possibility to define multiple values to particular items
-        return v[-1], h
-    else:
-        return v, h
+    return v, h
 
 
 def _get_procedure_implementation(name='*', ds=None):
-    """get potential procedure path and configuration
+    """get potential procedures: path, name, configuration, and a help message
 
-    Order of consideration is user-level, system-level, dataset,
-    datalad extensions, datalad. First one found according to this order is the
-    one to be returned. Therefore local definitions/configurations take
+    The order of consideration is user-level, system-level, extra locations, dataset,
+    datalad extensions, datalad. Therefore local definitions/configurations take
     precedence over ones, that come from outside (via a datalad-extension or a
     dataset with its .datalad/config). If a dataset had precedence (as it was
     before), the addition (or just an update) of a (sub-)dataset would otherwise
-    surprisingly cause you do execute code different from what you defined
+    surprisingly cause you to execute code different from what you defined
     within ~/.gitconfig or your local repository's .git/config.
     So, local definitions take precedence over remote ones and more specific
     ones over more general ones.
 
-    Returns
-    -------
+    Yields
+    ------
     tuple
       path, name, format string, help message
     """
@@ -121,14 +118,15 @@ def _get_procedure_implementation(name='*', ds=None):
 
     # 1. check system and user account for procedure
     for loc in (cfg.obtain('datalad.locations.user-procedures'),
-                cfg.obtain('datalad.locations.system-procedures')):
-        for dir in assure_list(loc):
+                cfg.obtain('datalad.locations.system-procedures'),
+                cfg.get('datalad.locations.extra-procedures', get_all=True)):
+        for dir in ensure_list(loc):
             for m, n in _get_file_match(dir, name):
                 yield (m, n,) + _get_proc_config(n)
     # 2. check dataset for procedure
     if ds is not None and ds.is_installed():
         # could be more than one
-        dirs = assure_list(
+        dirs = ensure_list(
                 ds.config.obtain('datalad.locations.dataset-procedures'))
         for dir in dirs:
             # TODO `get` dirs if necessary
@@ -439,7 +437,7 @@ class RunProcedure(Interface):
         cmd = ex['template'].format(
             script=guard_for_format(quote_cmdlinearg(procedure_file)),
             ds=guard_for_format(quote_cmdlinearg(ds.path)) if ds else '',
-            args=(u' '.join(quote_cmdlinearg(a) for a in args) if args else ''))
+            args=join_cmdline(args) if args else '')
         lgr.info(u"Running procedure %s", name)
         lgr.debug(u'Full procedure command: %r', cmd)
         for r in Run.__call__(
@@ -454,6 +452,16 @@ class RunProcedure(Interface):
         ):
             yield r
 
+        if ds:
+            # the procedure ran and we have to anticipate that it might have
+            # changed the dataset config, so we need to trigger an unforced
+            # reload.
+            # we have to do this despite "being done here", because
+            # run_procedure() runs in the same process and reuses dataset (config
+            # manager) instances, and the next interaction with a dataset should
+            # be able to count on an up-to-date config
+            ds.config.reload()
+
     @staticmethod
     def custom_result_renderer(res, **kwargs):
         from datalad.ui import ui
