@@ -15,28 +15,33 @@ __docformat__ = 'restructuredtext'
 import os.path as op
 import sys
 
-from datalad.cmd import Runner
+from datalad.cmd import (
+    WitlessRunner,
+    KillOutput,
+)
 from datalad.utils import (
     chpwd,
     quote_cmdlinearg,
     swallow_outputs,
 )
 from datalad.tests.utils import (
-    eq_,
-    ok_file_has_content,
-    with_tree,
-    with_tempfile,
-    assert_raises,
-    assert_repo_status,
-    assert_true,
+    OBSCURE_FILENAME,
     assert_false,
     assert_in_results,
     assert_not_in_results,
-    skip_if,
-    OBSCURE_FILENAME,
-    on_windows,
+    assert_raises,
+    assert_repo_status,
+    assert_result_count,
+    assert_true,
+    eq_,
     known_failure_windows,
+    ok_file_has_content,
+    on_windows,
+    patch_config,
+    skip_if,
     skip_if_on_windows,
+    with_tempfile,
+    with_tree,
 )
 from datalad.distribution.dataset import Dataset
 from datalad.support.exceptions import (
@@ -84,7 +89,12 @@ from datalad.api import save, Dataset
 with open(op.join(sys.argv[1], 'fromproc.txt'), 'w') as f:
     f.write('hello\\n')
 save(dataset=Dataset(sys.argv[1]), path='fromproc.txt')
-"""}})
+"""},
+    'cfg_yoda.sh': """\
+#!/bin/bash
+echo "I am never to be ran but could be discovered"
+exit 1
+"""})
 @with_tempfile
 def test_procedure_discovery(path, super_path):
     with chpwd(path):
@@ -94,17 +104,44 @@ def test_procedure_discovery(path, super_path):
         ps = run_procedure(discover=True)
         # there are a few procedures coming with datalad, needs to find them
         assert_true(len(ps) > 2)
-        # we get three essential properties
-        eq_(
-            sum(['procedure_type' in p and
-                 'procedure_callfmt' in p and
-                 'path' in p
-                 for p in ps]),
-            len(ps))
+        # we get essential properties
+        _check_procedure_properties(ps)
 
     # set up dataset with registered procedure (c&p from test_basics):
     ds = Dataset(path).create(force=True)
+    # extra check: must not pick up cfg_yoda.sh in top directory
     ds.run_procedure('cfg_yoda')
+
+    # path to a procedure which is not under any "standard" location but
+    # present in the dataset
+    code_dir_procedure_path = op.join(ds.path, 'code', 'datalad_test_proc.py')
+    top_dir_procedure_path = op.join(ds.path, 'cfg_yoda.sh')
+
+    # run discovery on the dataset:
+    ps = ds.run_procedure(discover=True)
+    # it should not be found magically by default
+    assert_not_in_results(ps, path=code_dir_procedure_path)
+    assert_not_in_results(ps, path=top_dir_procedure_path)
+
+    with patch_config({'datalad.locations.extra-procedures': op.join(ds.path, 'code')}):
+        # run discovery on the dataset:
+        ps = ds.run_procedure(discover=True)
+        # still needs to find procedures coming with datalad
+        assert_true(len(ps) > 3)
+        # and procedure under the path we specified
+        assert_result_count(ps, 1, path=code_dir_procedure_path)
+        assert_not_in_results(ps, path=top_dir_procedure_path)
+
+    # multiple extra locations
+    with patch_config({'datalad.locations.extra-procedures': [op.join(ds.path, 'code'), ds.path]}):
+        # run discovery on the dataset:
+        ps = ds.run_procedure(discover=True)
+        # still needs to find procedures coming with datalad
+        assert_true(len(ps) > 4)
+        # and procedure under the path we specified
+        assert_result_count(ps, 1, path=code_dir_procedure_path)
+        assert_result_count(ps, 1, path=top_dir_procedure_path)
+
     # configure dataset to look for procedures in its code folder
     ds.config.add(
         'datalad.locations.dataset-procedures',
@@ -118,14 +155,10 @@ def test_procedure_discovery(path, super_path):
     # still needs to find procedures coming with datalad
     assert_true(len(ps) > 2)
     # we get three essential properties
-    eq_(
-        sum(['procedure_type' in p and
-             'procedure_callfmt' in p and
-             'path' in p
-             for p in ps]),
-        len(ps))
+    _check_procedure_properties(ps)
     # dataset's procedure needs to be in the results
-    assert_in_results(ps, path=op.join(ds.path, 'code', 'datalad_test_proc.py'))
+    # and only a single one
+    assert_result_count(ps, 1, path=code_dir_procedure_path)
     # a subdir shouldn't be considered a procedure just because it's "executable"
     assert_not_in_results(ps, path=op.join(ds.path, 'code', 'testdir'))
 
@@ -138,13 +171,7 @@ def test_procedure_discovery(path, super_path):
     ps = super.run_procedure(discover=True)
     # still needs to find procedures coming with datalad
     assert_true(len(ps) > 2)
-    # we get three essential properties
-    eq_(
-        sum(['procedure_type' in p and
-             'procedure_callfmt' in p and
-             'path' in p
-             for p in ps]),
-        len(ps))
+    _check_procedure_properties(ps)
     # dataset's procedure needs to be in the results
     assert_in_results(ps, path=op.join(super.path, 'sub', 'code',
                                        'datalad_test_proc.py'))
@@ -174,6 +201,16 @@ def test_procedure_discovery(path, super_path):
             state='absent')
 
 
+def _check_procedure_properties(ps):
+    """a common check that we get three essential properties"""
+    eq_(
+        sum(['procedure_type' in p and
+             'procedure_callfmt' in p and
+             'path' in p
+             for p in ps]),
+        len(ps))
+
+
 @skip_if(cond=on_windows and dl_cfg.obtain("datalad.repo.version") < 6)
 @with_tree(tree={
     'code': {'datalad_test_proc.py': """\
@@ -299,11 +336,14 @@ def test_quoting(path):
         with assert_raises(CommandError):
             ds.run_procedure(spec=["just2args", "still-one arg"])
 
-        runner = Runner(cwd=ds.path)
+        runner = WitlessRunner(cwd=ds.path)
         runner.run(
-            "datalad run-procedure just2args \"with ' sing\" 'with \" doub'")
+            "datalad run-procedure just2args \"with ' sing\" 'with \" doub'",
+            protocol=KillOutput)
         with assert_raises(CommandError):
-            runner.run("datalad run-procedure just2args 'still-one arg'")
+            runner.run(
+                "datalad run-procedure just2args 'still-one arg'",
+                protocol=KillOutput)
 
 
 @skip_if_on_windows
