@@ -8,7 +8,15 @@
 # ## ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ##
 """Test XMP extractor"""
 
-from datalad.tests.utils import SkipTest
+from datalad.tests.utils import (
+    assert_in,
+    assert_repo_status,
+    assert_result_count,
+    assert_status,
+    eq_,
+    SkipTest,
+    with_tempfile,
+)
 try:
     import libxmp
 except Exception as exc:
@@ -16,15 +24,11 @@ except Exception as exc:
     raise SkipTest("libxmp cannot be imported: %s" % exc_str(exc))
 
 from shutil import copy
-from os.path import dirname
-from os.path import join as opj
+from os.path import (
+    dirname,
+    join as opj,
+)
 from datalad.api import Dataset
-from datalad.tests.utils import with_tempfile
-from datalad.tests.utils import ok_clean_git
-from datalad.tests.utils import assert_status
-from datalad.tests.utils import assert_result_count
-from datalad.tests.utils import eq_
-from datalad.tests.utils import assert_in
 
 
 target = {
@@ -50,7 +54,7 @@ def test_xmp(path):
         opj(dirname(dirname(dirname(__file__))), 'tests', 'data', 'xmp.pdf'),
         path)
     ds.save()
-    ok_clean_git(ds.path)
+    assert_repo_status(ds.path)
     res = ds.aggregate_metadata()
     assert_status('ok', res)
     res = ds.metadata('xmp.pdf')
