@@ -19,7 +19,6 @@ import os.path as op
 from collections import (
     OrderedDict,
 )
-from collections.abc import Mapping
 
 from datalad import cfg
 from datalad.interface.annotate_paths import AnnotatePaths
@@ -28,6 +27,7 @@ from datalad.interface.results import get_status_dict
 from datalad.interface.utils import eval_results
 from datalad.interface.base import build_doc
 from datalad.metadata.definitions import version as vocabulary_version
+from datalad.support.collections import ReadOnlyDict, _val2hashable
 from datalad.support.constraints import (
     EnsureNone,
     EnsureBool,
@@ -52,7 +52,7 @@ from datalad.distribution.dataset import (
     require_dataset,
 )
 from datalad.utils import (
-    assure_list,
+    ensure_list,
     path_is_subpath,
     path_startswith,
     as_unicode,
@@ -465,7 +465,7 @@ def _get_metadata(ds, types, global_meta=None, content_meta=None, paths=None):
             )
 
     # pull out potential metadata field blacklist config settings
-    blacklist = [re.compile(bl) for bl in assure_list(ds.config.obtain(
+    blacklist = [re.compile(bl) for bl in ensure_list(ds.config.obtain(
         'datalad.metadata.aggregate-ignore-fields',
         default=[]))]
     # enforce size limits
@@ -702,62 +702,6 @@ def _unique_value_key(x):
     return as_unicode(x)
 
 
-def _val2hashable(val):
-    """Small helper to convert incoming mutables to something hashable
-
-    The goal is to be able to put the return value into a set, while
-    avoiding conversions that would result in a change of representation
-    in a subsequent JSON string.
-    """
-    if isinstance(val, dict):
-        return ReadOnlyDict(val)
-    elif isinstance(val, list):
-        return tuple(map(_val2hashable, val))
-    else:
-        return val
-
-
-class ReadOnlyDict(Mapping):
-    # Taken from https://github.com/slezica/python-frozendict
-    # License: MIT
-    """
-    An immutable wrapper around dictionaries that implements the complete
-    :py:class:`collections.Mapping` interface. It can be used as a drop-in
-    replacement for dictionaries where immutability is desired.
-    """
-    dict_cls = dict
-
-    def __init__(self, *args, **kwargs):
-        self._dict = self.dict_cls(*args, **kwargs)
-        self._hash = None
-
-    def __getitem__(self, key):
-        return self._dict[key]
-
-    def __contains__(self, key):
-        return key in self._dict
-
-    def copy(self, **add_or_replace):
-        return self.__class__(self, **add_or_replace)
-
-    def __iter__(self):
-        return iter(self._dict)
-
-    def __len__(self):
-        return len(self._dict)
-
-    def __repr__(self):
-        return '<%s %r>' % (self.__class__.__name__, self._dict)
-
-    def __hash__(self):
-        if self._hash is None:
-            h = 0
-            for key, value in self._dict.items():
-                h ^= hash((key, _val2hashable(value)))
-            self._hash = h
-        return self._hash
-
-
 def get_ds_aggregate_db_locations(ds, version='default', warn_absent=True):
     """Returns the location of a dataset's aggregate metadata DB
 
@@ -797,7 +741,7 @@ def get_ds_aggregate_db_locations(ds, version='default', warn_absent=True):
             # caller had no specific idea what metadata version is needed/available
             # This dataset does not have aggregated metadata.  Does it have any
             # other version?
-            info_glob = op.join(ds.path, agginfo_relpath_template).format('*')
+            info_glob = op.join(ds.path, agginfo_relpath_template.format('*'))
             info_files = glob.glob(info_glob)
             msg = "Found no aggregated metadata info file %s." \
                   % info_fpath
@@ -1080,4 +1024,4 @@ class Metadata(Interface):
                           if k not in ('tag', '@context', '@id'))
                  if meta else ' -' if 'metadata' in res else ' aggregated',
             tags='' if 'tag' not in meta else ' [{}]'.format(
-                 ','.join(assure_list(meta['tag'])))))
+                 ','.join(ensure_list(meta['tag'])))))
