@@ -21,9 +21,11 @@ from unittest.mock import patch
 from io import StringIO
 
 from datalad.api import addurls, Dataset, subdatasets
+from datalad.cmd import WitlessRunner
 from datalad.consts import WEB_SPECIAL_REMOTE_UUID
 import datalad.plugin.addurls as au
 from datalad.support.exceptions import IncompleteResultsError
+from datalad.support.external_versions import external_versions
 from datalad.tests.utils import (
     assert_dict_equal,
     assert_false,
@@ -33,6 +35,7 @@ from datalad.tests.utils import (
     assert_raises,
     assert_re_in,
     assert_repo_status,
+    assert_result_count,
     assert_true,
     chpwd,
     create_tree,
@@ -40,10 +43,14 @@ from datalad.tests.utils import (
     HTTPPath,
     known_failure_githubci_win,
     ok_exists,
+    ok_startswith,
+    skip_if,
+    SkipTest,
     swallow_logs,
     with_tempfile,
     with_tree,
     on_windows,
+    DEFAULT_BRANCH,
 )
 from datalad.utils import get_tempfile_kwargs, rmtemp
 from datalad import cfg as dl_cfg
@@ -249,7 +256,7 @@ def json_stream(data):
 @known_failure_githubci_win
 def test_extract():
     info, subpaths = au.extract(
-        json_stream(ST_DATA["rows"]), "json",
+        ST_DATA["rows"],
         url_format="{name}_{debut_season}.com",
         filename_format="{age_group}//{now_dead}//{name}.csv")
 
@@ -280,7 +287,7 @@ def test_extract():
 
 def test_extract_disable_autometa():
     info, _ = au.extract(
-        json_stream(ST_DATA["rows"]), "json",
+        ST_DATA["rows"],
         url_format="{name}_{debut_season}.com",
         filename_format="{age_group}//{now_dead}//{name}.csv",
         exclude_autometa="*",
@@ -293,7 +300,7 @@ def test_extract_disable_autometa():
 
 def test_extract_exclude_autometa_regexp():
     info, _ = au.extract(
-        json_stream(ST_DATA["rows"]), "json",
+        ST_DATA["rows"],
         url_format="{name}_{debut_season}.com",
         filename_format="{age_group}//{now_dead}//{name}.csv",
         exclude_autometa="ea")
@@ -306,25 +313,34 @@ def test_extract_exclude_autometa_regexp():
         assert_dict_equal(d["meta_args"], expect)
 
 
-def test_extract_csv_json_equal():
+def check_extract_csv_json_equal(input_type):
+    delim = "\t" if input_type == "tsv" else ","
+
     keys = ST_DATA["header"]
-    csv_rows = [",".join(keys)]
-    csv_rows.extend(",".join(str(row[k]) for k in keys)
+    csv_rows = [delim.join(keys)]
+    csv_rows.extend(delim.join(str(row[k]) for k in keys)
                     for row in ST_DATA["rows"])
 
     kwds = dict(filename_format="{age_group}//{now_dead}//{name}.csv",
                 url_format="{name}_{debut_season}.com",
                 meta=["group={age_group}"])
 
-    json_output = au.extract(json_stream(ST_DATA["rows"]), "json", **kwds)
-    csv_output = au.extract(csv_rows, "csv", **kwds)
+    json_output = au.extract(
+        *au._read(json_stream(ST_DATA["rows"]), "json"), **kwds)
+    csv_output = au.extract(
+        *au._read(csv_rows, input_type), **kwds)
 
     eq_(json_output, csv_output)
 
 
+def test_extract_csv_tsv_json_equal():
+    yield check_extract_csv_json_equal, "csv"
+    yield check_extract_csv_json_equal, "tsv"
+
+
 def test_extract_wrong_input_type():
     assert_raises(ValueError,
-                  au.extract, None, "not_csv_or_json")
+                  au._read, None, "invalid_input_type")
 
 
 @with_tempfile(mkdir=True)
@@ -394,6 +410,12 @@ def test_addurls_dry_run(path):
                   cml.out)
 
 
+OLD_EXAMINEKEY = external_versions["cmd:annex"] < "8.20201116"
+skip_key_tests = skip_if(
+    OLD_EXAMINEKEY,
+    "git-annex version does not support `examinekey --migrate-to-backend`")
+
+
 class TestAddurls(object):
 
     @classmethod
@@ -409,13 +431,24 @@ class TestAddurls(object):
         cls._hpath.start()
         cls.url = cls._hpath.url
 
+        cls.data = [{"url": cls.url + "udir/a.dat",
+                     "name": "a",
+                     "subdir": "foo",
+                     "md5sum": "3fb7c40c70b0ed19da713bd69ee12014",
+                     "size": "9"},
+                    {"url": cls.url + "udir/b.dat",
+                     "name": "b",
+                     "subdir": "bar",
+                     "md5sum": "",
+                     "size": ""},
+                    {"url": cls.url + "udir/c.dat",
+                     "name": "c",
+                     "subdir": "foo",
+                     "md5sum": "9b72648021b70b8c522642e4490d7ac3",
+                     "size": "9"}]
         cls.json_file = tempfile.mktemp(suffix=".json", **mktmp_kws)
         with open(cls.json_file, "w") as jfh:
-            json.dump(
-                [{"url": cls.url + "udir/a.dat", "name": "a", "subdir": "foo"},
-                 {"url": cls.url + "udir/b.dat", "name": "b", "subdir": "bar"},
-                 {"url": cls.url + "udir/c.dat", "name": "c", "subdir": "foo"}],
-                jfh)
+            json.dump(cls.data, jfh)
 
     @classmethod
     def teardown_class(cls):
@@ -431,7 +464,15 @@ class TestAddurls(object):
 
         n_annex_commits = get_annex_commit_counts()
 
-        ds.addurls(self.json_file, "{url}", "{name}")
+        # Meanwhile also test that we can specify path relative
+        # to the top of the dataset, as we generally treat paths in
+        # Python API, and it will be the one saved in commit
+        # message record
+        json_file = op.relpath(self.json_file, ds.path)
+
+        ds.addurls(json_file, "{url}", "{name}",
+                   exclude_autometa="(md5sum|size)")
+        ok_startswith(ds.repo.format_commit('%b', DEFAULT_BRANCH), f"url_file='{json_file}'")
 
         filenames = ["a", "b", "c"]
         for fname in filenames:
@@ -513,6 +554,13 @@ class TestAddurls(object):
         for fname in ["a", "b", "c", "code"]:
             ok_exists(os.path.join(dspath, fname))
 
+    @with_tempfile
+    def test_addurls_from_list(self, path):
+        ds = Dataset(path).create()
+        ds.addurls(self.data, "{url}", "{name}")
+        for fname in ["a", "b", "c"]:
+            ok_exists(op.join(path, fname))
+
     @with_tempfile(mkdir=True)
     def test_addurls_subdataset(self, path):
         ds = Dataset(path).create(force=True)
@@ -536,8 +584,8 @@ class TestAddurls(object):
             if save:
                 assert_repo_status(path)
             else:
-                # The datasets are create and saved ...
-                assert_repo_status(path, modified=subdirs)
+                # The datasets are create but not saved (since asked not to)
+                assert_repo_status(path, untracked=subdirs)
                 # but the downloaded files aren't.
                 for subds, fnames in subdir_files.items():
                     assert_repo_status(subds, added=fnames)
@@ -643,7 +691,8 @@ class TestAddurls(object):
         ds = Dataset(path).create(force=True)
         ds.addurls(
             self.json_file, "{url}",
-            "{subdir}//adir/{subdir}-again//other-ds//bdir/{name}")
+            "{subdir}//adir/{subdir}-again//other-ds//bdir/{name}",
+            jobs=3)
         eq_(set(ds.subdatasets(recursive=True, result_xfm="relpaths")),
             {"foo",
              "bar",
@@ -658,19 +707,142 @@ class TestAddurls(object):
     def test_addurls_invalid_input(self, path):
         ds = Dataset(path).create(force=True)
         in_file = op.join(path, "in")
-        for in_type in ["csv", "json"]:
+        for in_type in au.INPUT_TYPES:
             with assert_raises(IncompleteResultsError) as exc:
                 ds.addurls(in_file, "{url}", "{name}", input_type=in_type)
             assert_in("Failed to read", str(exc.exception))
 
     @with_tree({"in.csv": "url,name,subdir",
+                "in.tsv": "url\tname\tsubdir",
                 "in.json": "[]"})
     def test_addurls_no_rows(self, path):
         ds = Dataset(path).create(force=True)
-        for fname in ["in.csv", "in.json"]:
+        for fname in ["in.csv", "in.tsv", "in.json"]:
             with swallow_logs(new_level=logging.WARNING) as cml:
                 assert_in_results(
                     ds.addurls(fname, "{url}", "{name}"),
                     action="addurls",
                     status="notneeded")
                 cml.assert_logged("No rows", regex=False)
+
+    @with_tempfile(mkdir=True)
+    def check_addurls_stdin_input(self, input_text, input_type, path):
+        ds = Dataset(path).create(force=True)
+        with patch("sys.stdin", new=StringIO(input_text)):
+            ds.addurls("-", "{url}", "{name}", input_type=input_type)
+        for fname in ["a", "b", "c"]:
+            ok_exists(op.join(ds.path, fname))
+
+    def test_addurls_stdin_input(self):
+        def make_test(text, input_type, description):
+            def fn():
+                self.check_addurls_stdin_input(json_text, "ext")
+            fn.description = description
+            return fn
+
+        with open(self.json_file) as jfh:
+            json_text = jfh.read()
+
+        yield make_test(json_text, "ext", "json,default input type")
+        yield make_test(json_text, "json", "json,json input type")
+
+        def make_delim_text(delim):
+            row = "{name}" + delim + "{url}"
+            return "\n".join(
+                [row.format(name="name", url="url")] +
+                [row.format(**rec) for rec in json.loads(json_text)])
+
+        yield make_test(make_delim_text(","), "csv", "csv,csv input type")
+        yield make_test(make_delim_text("\t"), "tsv", "tsv,tsv input type")
+
+    @with_tempfile(mkdir=True)
+    def test_addurls_stdin_input_command_line(self, path):
+        # The previous test checks all the cases, but it overrides sys.stdin.
+        # Do a simple check that's closer to a command line call.
+        Dataset(path).create(force=True)
+        runner = WitlessRunner(cwd=path)
+        with open(self.json_file) as jfh:
+            runner.run(["datalad", "addurls", '-', '{url}', '{name}'],
+                       stdin=jfh)
+        for fname in ["a", "b", "c"]:
+            ok_exists(op.join(path, fname))
+
+    @with_tempfile(mkdir=True)
+    def test_drop_after(self, path):
+        ds = Dataset(path).create(force=True)
+        ds.repo.set_gitattributes([('a*', {'annex.largefiles': 'nothing'})])
+        # make some files go to git, so we could test that we do not blow
+        # while trying to drop what is in git not annex
+        res = ds.addurls(self.json_file, '{url}', '{name}', drop_after=True)
+
+        assert_result_count(res, 3, action='addurl', status='ok')  # a, b, c  even if a goes to git
+        assert_result_count(res, 2, action='drop', status='ok')  # b, c
+
+    @with_tempfile(mkdir=True)
+    def test_addurls_from_key_invalid_format(self, path):
+        ds = Dataset(path).create(force=True)
+        for fmt in ["{name}-which-has-no-double-dash",
+                    # Invalid hash length.
+                    "MD5-s{size}--{md5sum}a",
+                    # Invalid hash content.
+                    "MD5-s{size}--" + 32 * "q"]:
+            with assert_raises(IncompleteResultsError):
+                ds.addurls(self.json_file, "{url}", "{name}",
+                           key=fmt, exclude_autometa="*")
+
+    @with_tempfile(mkdir=True)
+    def check_addurls_from_key(self, key_arg, expected_backend, fake_dates,
+                               path):
+        ds = Dataset(path).create(force=True, fake_dates=fake_dates)
+        if OLD_EXAMINEKEY and ds.repo.is_managed_branch():
+            raise SkipTest("Adjusted branch functionality requires "
+                           "more recent `git annex examinekey`")
+        ds.addurls(self.json_file, "{url}", "{name}", exclude_autometa="*",
+                   key=key_arg)
+        repo = ds.repo
+        repo_path = ds.repo.pathobj
+        paths = [repo_path / x for x in "ac"]
+
+        annexinfo = repo.get_content_annexinfo(eval_availability=True)
+        for path in paths:
+            pstat = annexinfo[path]
+            eq_(pstat["backend"], expected_backend)
+            assert_false(pstat["has_content"])
+
+        get_res = ds.get(paths, result_renderer=None, on_failure="ignore")
+        assert_result_count(get_res, 2, action="get", status="ok")
+
+    def test_addurls_from_key(self):
+        fn = self.check_addurls_from_key
+        for case in [
+                (fn, "MD5-s{size}--{md5sum}", "MD5"),
+                (fn, "MD5E-s{size}--{md5sum}.dat", "MD5E"),
+                (skip_key_tests(fn), "et:MD5-s{size}--{md5sum}", "MD5E"),
+                (skip_key_tests(fn), "et:MD5E-s{size}--{md5sum}.dat", "MD5")]:
+            yield case + (False,)
+            yield case + (True,)
+
+    @with_tempfile(mkdir=True)
+    def test_addurls_row_missing_key_fields(self, path):
+        ds = Dataset(path).create(force=True)
+        if OLD_EXAMINEKEY and ds.repo.is_managed_branch():
+            raise SkipTest("Adjusted branch functionality requires "
+                           "more recent `git annex examinekey`")
+        data = self.data.copy()
+        for row in data:
+            if row["name"] == "b":
+                del row["md5sum"]
+                break
+        with patch("sys.stdin", new=StringIO(json.dumps(data))):
+            ds.addurls("-", "{url}", "{name}", exclude_autometa="*",
+                       key="MD5-s{size}--{md5sum}")
+
+        repo = ds.repo
+        repo_path = ds.repo.pathobj
+        paths = [repo_path / x for x in "ac"]
+
+        annexinfo = repo.get_content_annexinfo(eval_availability=True)
+        for path in paths:
+            pstat = annexinfo[path]
+            eq_(pstat["backend"], "MD5")
+            assert_false(pstat["has_content"])
