@@ -42,24 +42,31 @@ class UnknownVersion:
 #
 # Custom handlers
 #
-from datalad.cmd import Runner
-from datalad.cmd import GitRunner
+from datalad.cmd import (
+    WitlessRunner,
+    GitWitlessRunner,
+    StdOutErrCapture,
+)
 from datalad.support.exceptions import (
     MissingExternalDependency,
     OutdatedExternalDependency,
 )
-_runner = Runner()
-_git_runner = GitRunner()
+_runner = WitlessRunner()
+_git_runner = GitWitlessRunner()
 
 
 def _get_annex_version():
     """Return version of available git-annex"""
     try:
-        return _runner.run('git annex version --raw'.split())[0]
+        return _runner.run(
+            'git annex version --raw'.split(),
+            protocol=StdOutErrCapture)['stdout']
     except CommandError:
         # fall back on method that could work with older installations
-        out, err = _runner.run(['git', 'annex', 'version'])
-        return out.split('\n')[0].split(':')[1].strip()
+        out = _runner.run(
+            ['git', 'annex', 'version'],
+            protocol=StdOutErrCapture)
+        return out['stdout'].splitlines()[0].split(':')[1].strip()
 
 
 def _get_git_version():
@@ -81,7 +88,9 @@ def _get_bundled_git_version():
     """
     path = _git_runner._get_bundled_path()
     if path:
-        out = _runner.run([op.join(path, "git"), "version"])[0]
+        out = _runner.run(
+            [op.join(path, "git"), "version"],
+            protocol=StdOutErrCapture)['stdout']
         # format: git version 2.22.0
         return out.split()[2]
 
@@ -92,30 +101,31 @@ def _get_system_ssh_version():
     Annex prior 20170302 was using bundled version, but now would use system one
     if installed
     """
-    out, err = _runner.run('ssh -V'.split(),
-                           expect_fail=True, expect_stderr=True)
+    out = _runner.run(
+        'ssh -V'.split(),
+        protocol=StdOutErrCapture)
     # apparently spits out to err but I wouldn't trust it blindly
-    if err.startswith('OpenSSH'):
-        out = err
-    assert out.startswith('OpenSSH')  # that is the only one we care about atm
-    return out.split(' ', 1)[0].rstrip(',.').split('_')[1]
+    stdout = out['stdout']
+    if out['stderr'].startswith('OpenSSH'):
+        stdout = out['stderr']
+    assert stdout.startswith('OpenSSH')  # that is the only one we care about atm
+    return stdout.split(' ', 1)[0].rstrip(',.').split('_')[1]
 
 
 def _get_system_7z_version():
     """Return version of 7-Zip"""
-    out, err = _runner.run(
-        ['7z'], expect_fail=True, expect_stderr=True,
-    )
+    out = _runner.run(
+        ['7z'],
+        protocol=StdOutErrCapture)
     # reporting in variable order across platforms
     # Linux: 7-Zip [64] 16.02
     # Windows: 7-Zip 19.00 (x86)
-    pieces = out.strip().split(':', maxsplit=1)[0].strip().split()
+    pieces = out['stdout'].strip().split(':', maxsplit=1)[0].strip().split()
     for p in pieces:
         # the one with the dot is the version
         if '.' in p:
             return p
-    lgr.debug("Could not determine version of 7z from stdout. "
-              "stdout: %s, stderr: %s", out, err)
+    lgr.debug("Could not determine version of 7z from stdout. %s", out)
 
 
 class ExternalVersions(object):
