@@ -30,8 +30,10 @@ from datalad.dochelpers import exc_str
 from datalad.support.exceptions import (
     DownloadError,
     AccessDeniedError,
+    AccessPermissionExpiredError,
     AnonymousAccessDeniedError,
 )
+from datalad.utils import try_multiple_dec
 
 from urllib.request import urlopen, Request
 
@@ -76,6 +78,47 @@ def _handle_exception(e, bucket_name):
         )
 
 
+def _check_S3ResponseError(e):
+    """Returns True if should be retried.
+
+    raises ... if token has expired"""
+    # https://docs.aws.amazon.com/AmazonS3/latest/API/ErrorResponses.html#ErrorCodeList
+    if e.status in (
+                    307,  # MovedTemporarily -- DNS updates etc
+                    503,  # Slow down -- too many requests, so perfect fit to sleep a bit
+                    ):
+        return True
+    if e.status == 400:
+        # Generic Bad Request -- could be many things! generally -- we retry, but
+        # some times provide more directed reaction
+        # ATM, as used, many requests we send with boto might be just HEAD requests
+        # (if I got it right) and we would not receive BODY back with the detailed
+        # error_code.  Then we will allow to retry until we get something we know how to
+        # handle it more specifically
+        if e.error_code == 'ExpiredToken':
+            raise AccessPermissionExpiredError("Used token to access S3 has expired: %s" % exc_str(e))
+        elif not e.error_code:
+            lgr.log(5, "Empty error_code in %s", e)
+        return True
+    return False
+
+
+def try_multiple_dec_s3(func):
+    """An S3 specific adapter to @try_multiple_dec
+
+    To decorate func to try multiple times after some sleep upon encountering
+    some intermittent error from S3
+    """
+    return try_multiple_dec(
+                ntrials=4,
+                duration=2.,
+                increment_type='exponential',
+                exceptions=S3ResponseError,
+                exceptions_filter=_check_S3ResponseError,
+                logger=lgr.debug,
+    )(func)
+
+
 def get_bucket(conn, bucket_name):
     """A helper to get a bucket
 
@@ -84,14 +127,14 @@ def get_bucket(conn, bucket_name):
     bucket_name: str
         Name of the bucket to connect to
     """
-    bucket = None
     try:
-        bucket = conn.get_bucket(bucket_name)
+        return try_multiple_dec_s3(conn.get_bucket)(bucket_name)
     except S3ResponseError as e:
         # can initially deny or error to connect to the specific bucket by name,
         # and we would need to list which buckets are available under following
         # credentials:
-        lgr.debug("Cannot access bucket %s by name: %s", bucket_name, exc_str(e))
+        lgr.debug("Cannot access bucket %s by name with validation: %s",
+                  bucket_name, exc_str(e))
         if conn.anon:
             raise AnonymousAccessDeniedError(
                 "Access to the bucket %s did not succeed.  Requesting "
@@ -99,19 +142,28 @@ def get_bucket(conn, bucket_name):
                 "little sense and thus not supported." % bucket_name,
                 supported_types=['aws-s3']
             )
-        all_buckets = []
+
+        if e.reason == "Forbidden":
+            # Could be just HEAD call boto issues is not allowed, and we should not
+            # try to verify that bucket is "reachable".  Just carry on
+            try:
+                return try_multiple_dec_s3(conn.get_bucket)(bucket_name, validate=False)
+            except S3ResponseError as e2:
+                lgr.debug("Cannot access bucket %s even without validation: %s",
+                          bucket_name, exc_str(e2))
+                _handle_exception(e, bucket_name)
+
         try:
-            all_buckets = conn.get_all_buckets()
+            all_buckets = try_multiple_dec_s3(conn.get_all_buckets)()
+            all_bucket_names = [b.name for b in all_buckets]
+            lgr.debug("Found following buckets %s", ', '.join(all_bucket_names))
+            if bucket_name in all_bucket_names:
+                return all_buckets[all_bucket_names.index(bucket_name)]
         except S3ResponseError as e2:
             lgr.debug("Cannot access all buckets: %s", exc_str(e2))
             _handle_exception(e, 'any (originally requested %s)' % bucket_name)
-        all_bucket_names = [b.name for b in all_buckets]
-        lgr.debug("Found following buckets %s", ', '.join(all_bucket_names))
-        if bucket_name in all_bucket_names:
-            bucket = all_buckets[all_bucket_names.index(bucket_name)]
         else:
             _handle_exception(e, bucket_name)
-    return bucket
 
 
 class VersionedFilesPool(object):
@@ -405,8 +457,8 @@ def get_versioned_url(url, guarantee_versioned=False, return_all=False, verify=F
     if url_rec.hostname.endswith('.s3.amazonaws.com'):
         if url_rec.scheme not in ('http', 'https'):
             raise ValueError("Do not know how to handle %s scheme" % url_rec.scheme)
-        # we know how to slice this cat
-        s3_bucket = url_rec.hostname.split('.', 1)[0]
+        # bucket name could have . in it, e.g. openneuro.org
+        s3_bucket = url_rec.hostname[:-len('.s3.amazonaws.com')]
     elif url_rec.hostname == 's3.amazonaws.com':
         if url_rec.scheme not in ('http', 'https'):
             raise ValueError("Do not know how to handle %s scheme" % url_rec.scheme)
@@ -431,11 +483,16 @@ def get_versioned_url(url, guarantee_versioned=False, return_all=False, verify=F
             providers = Providers.from_config_files()
             s3url = "s3://%s/" % s3_bucket
             s3provider = providers.get_provider(s3url)
-            if s3provider.authenticator.bucket is not None and s3provider.authenticator.bucket.name == s3_bucket:
+            authenticator = s3provider.authenticator
+            if not authenticator:
+                # We will use anonymous one
+                from ..downloaders.s3 import S3Authenticator
+                authenticator = S3Authenticator()
+            if authenticator.bucket is not None and authenticator.bucket.name == s3_bucket:
                 # we have established connection before, so let's just reuse
-                bucket = s3provider.authenticator.bucket
+                bucket = authenticator.bucket
             else:
-                bucket = s3provider.authenticator.authenticate(s3_bucket, s3provider.credential)  # s3conn or _get_bucket_connection(S3_TEST_CREDENTIAL)
+                bucket = authenticator.authenticate(s3_bucket, s3provider.credential)  # s3conn or _get_bucket_connection(S3_TEST_CREDENTIAL)
         else:
             bucket = s3conn.get_bucket(s3_bucket)
 
