@@ -14,6 +14,7 @@ import datalad.utils as ut
 from datalad.tests.utils import (
     assert_dict_equal,
     assert_equal,
+    assert_false,
     assert_in,
     assert_not_in,
     assert_raises,
@@ -271,3 +272,11 @@ def test_info_path_inside_submodule(path):
     cinfo = ds.repo.get_content_info(
         ref="HEAD", paths=[foo.relative_to(ds.pathobj)])
     assert_in("gitshasum", cinfo[subds.pathobj])
+
+
+@with_tempfile
+def test_get_content_info_dotgit(path):
+    ds = Dataset(path).create()
+    # Files in .git/ won't be reported, though this takes a kludge on our side
+    # before Git 2.25.
+    assert_false(ds.repo.get_content_info(paths=[op.join(".git", "config")]))
