@@ -8,10 +8,11 @@
 # ## ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ##
 
 from ..versions import get_versions
-from ...tests.utils import assert_equal, assert_false
-from ...tests.utils import assert_raises
-from ...support.status import FileStatus
-from nose.tools import assert_not_equal
+from datalad.tests.utils import (
+    assert_equal,
+    assert_raises,
+)
+from datalad.support.status import FileStatus
 from collections import OrderedDict as od
 
 
