@@ -9,11 +9,15 @@
 import sys
 import json
 
-from six.moves.urllib.request import Request, urlopen
-from six.moves.urllib.error import HTTPError
+from urllib.request import Request
+from urllib.request import urlopen
+from urllib.error import HTTPError
 
-from datalad.downloaders.base import AccessDeniedError, AccessFailedError
-from datalad.utils import assure_unicode
+from datalad.support.exceptions import (
+    AccessDeniedError,
+    AccessFailedError,
+)
+from datalad.utils import ensure_unicode
 
 
 class LORISTokenGenerator(object):
@@ -40,7 +44,7 @@ class LORISTokenGenerator(object):
         except HTTPError:
             raise AccessDeniedError("Could not authenticate into LORIS")
 
-        str_response = assure_unicode(response.read())
+        str_response = ensure_unicode(response.read())
         data = json.loads(str_response)
         return data["token"]
 
