@@ -10,14 +10,16 @@
 
 """
 
-from ..support.network import URL
-from ..support.s3 import add_version_to_url, get_versioned_url
-from .utils import use_cassette
-from .utils import ok_startswith
-
-from nose.tools import eq_, assert_raises
-from datalad.tests.utils import skip_if_no_network
-from ..downloaders.tests.utils import get_test_providers
+from datalad.support.network import URL
+from datalad.support.s3 import add_version_to_url, get_versioned_url
+from datalad.tests.utils import (
+    assert_raises,
+    eq_,
+    ok_startswith,
+    skip_if_no_network,
+    use_cassette,
+)
+from datalad.downloaders.tests.utils import get_test_providers
 
 
 def test_add_version_to_url():
@@ -86,6 +88,16 @@ def test_get_versioned_url():
         url_3ver + "?versionId=Kvuind11HZh._dCPaDAb0OY9dRrQoTMn")
 
 
+@skip_if_no_network
+@use_cassette('s3_test_version_url_anon')
+def test_get_versioned_url_anon():
+    # The one without any authenticator, was crashing.
+    # Also it triggered another bug about having . in the bucket name
+    url_on = "http://openneuro.org.s3.amazonaws.com/ds000001/dataset_description.json"
+    url_on_versioned = get_versioned_url(url_on)
+    ok_startswith(url_on_versioned, url_on + "?versionId=")
+
+
 @skip_if_no_network
 @use_cassette('s3_test_version_url_deleted')
 def test_version_url_deleted():
@@ -98,4 +110,4 @@ def test_version_url_deleted():
            "?versionId=eZ5Hgwo8azfBv3QT7aW9dmm2sbLUY.QP" % fpath
     eq_(get_versioned_url(url), turl)
     # too heavy for verification!
-    #eq_(get_versioned_url(url, verify=True), turl)
\ No newline at end of file
+    #eq_(get_versioned_url(url, verify=True), turl)
