@@ -17,7 +17,10 @@ from datalad.tests.utils import (
     with_testrepos,
     with_tempfile,
 )
-from datalad.cmd import Runner
+from datalad.cmd import (
+    StdOutErrCapture,
+    WitlessRunner,
+)
 from .utils_testdatasets import make_studyforrest_mockup
 
 
@@ -42,8 +45,8 @@ def test_point_to_github(url):
 @with_tempfile
 def test_clone(src, tempdir):
     # Verify that all our repos are clonable
-    r = Runner()
-    output = r.run(["git" , "clone", src, tempdir], log_online=True)
+    r = WitlessRunner()
+    output = r.run(["git" , "clone", src, tempdir], protocol=StdOutErrCapture)
     #status, output = getstatusoutput("git clone %(src)s %(tempdir)s" % locals())
     ok_(os.path.exists(os.path.join(tempdir, ".git")))
     # TODO: requires network for sure! ;)
