@@ -25,6 +25,7 @@ from datalad.tests.utils import (
     assert_raises,
     assert_result_count,
     assert_true,
+    known_failure_windows,
     skip_if_no_network,
     with_tempfile
 )
@@ -152,6 +153,7 @@ def test_get_cached_dataset(cache_dir):
             assert_is(ds, ds2)
 
 
+@known_failure_windows
 @skip_if_no_network
 @with_tempfile(mkdir=True)
 def test_cached_dataset(cache_dir):
@@ -253,6 +255,7 @@ def test_cached_dataset(cache_dir):
         assert_not_equal(first_repopath, second_repopath)
 
 
+@known_failure_windows
 @skip_if_no_network
 @with_tempfile(mkdir=True)
 def test_cached_url(cache_dir):
